@@ -5,18 +5,20 @@ class Admin::SpamLogsController < Admin::ApplicationController
 
   # rubocop: disable CodeReuse/ActiveRecord
   def index
-    @spam_logs = SpamLog.order(id: :desc).page(params[:page])
+    @spam_logs = SpamLog.preload(user: [:trusted_with_spam_attribute])
+      .order(id: :desc)
+      .page(pagination_params[:page]).without_count
   end
   # rubocop: enable CodeReuse/ActiveRecord
 
   def destroy
-    spam_log = SpamLog.find(params[:id])
+    spam_log = SpamLog.find(safe_params[:id])
 
-    if params[:remove_user]
+    if safe_params[:remove_user]
       spam_log.remove_user(deleted_by: current_user)
       redirect_to admin_spam_logs_path,
-                  status: :found,
-                  notice: _('User %{username} was successfully removed.') % { username: spam_log.user.username }
+        status: :found,
+        notice: format(_('User %{username} was successfully removed.'), username: spam_log.user.username)
     else
       spam_log.destroy
       head :ok
@@ -24,7 +26,7 @@ class Admin::SpamLogsController < Admin::ApplicationController
   end
 
   def mark_as_ham
-    spam_log = SpamLog.find(params[:id])
+    spam_log = SpamLog.find(safe_params[:id])
 
     if Spam::HamService.new(spam_log).execute
       redirect_to admin_spam_logs_path, notice: _('Spam log successfully submitted as ham.')
@@ -32,4 +34,10 @@ class Admin::SpamLogsController < Admin::ApplicationController
       redirect_to admin_spam_logs_path, alert: _('Error with Akismet. Please check the logs for more info.')
     end
   end
+
+  private
+
+  def safe_params
+    params.permit(:id, :remove_user)
+  end
 end
