@@ -1,7 +1,6 @@
 # frozen_string_literal: true
 
 require 'gon'
-require 'fogbugz'
 
 class ApplicationController < BaseActionController
   use Gitlab::Middleware::ActionControllerStaticContext
@@ -30,7 +29,6 @@ class ApplicationController < BaseActionController
   include StrongPaginationParams
   include Gitlab::HttpRouter::RuleContext
   include Gitlab::HttpRouter::RuleMetrics
-  include ViteCSP
 
   around_action :set_current_ip_address
 
@@ -47,6 +45,9 @@ class ApplicationController < BaseActionController
   before_action :set_usage_stats_consent_flag
   before_action :check_impersonation_availability
   before_action :increment_http_router_metrics
+  before_action only: :show do
+    push_frontend_feature_flag(:duo_side_rail, current_user)
+  end
 
   # Make sure the `auth_user` is memoized so it can be logged, we do this after
   # all other before filters that could have set the user.
@@ -139,7 +140,7 @@ class ApplicationController < BaseActionController
     else
       store_location_for(:user, request.fullpath) unless request.xhr?
 
-      redirect_to new_user_session_path, alert: I18n.t('devise.failure.unauthenticated')
+      redirect_to new_user_session_path, notice: I18n.t('devise.failure.unauthenticated')
     end
   end
 
@@ -441,13 +442,6 @@ class ApplicationController < BaseActionController
     Gitlab::CurrentSettings.import_sources.include?('manifest')
   end
 
-  # U2F (universal 2nd factor) devices need a unique identifier for the application
-  # to perform authentication.
-  # https://developers.yubico.com/U2F/App_ID.html
-  def u2f_app_id
-    request.base_url
-  end
-
   def set_current_context(&block)
     # even though feature_category is pre-populated by
     # Gitlab::Middleware::ActionControllerStaticContext
@@ -550,15 +544,11 @@ class ApplicationController < BaseActionController
     auth_user if strong_memoized?(:auth_user)
   end
 
-  def set_current_organization
-    return if ::Current.organization_assigned
-
-    ::Current.organization = Gitlab::Current::Organization.new(
-      params: params.permit(
-        :controller, :namespace_id, :group_id, :id, :organization_path
-      ),
-      user: current_user
-    ).organization
+  # Used by `set_current_organization` in BaseActionController
+  def organization_params
+    params.permit(
+      :controller, :namespace_id, :group_id, :id, :organization_path
+    )
   end
 end
 
