@@ -4,7 +4,6 @@ module Snippets::BlobsActions
   extend ActiveSupport::Concern
 
   include Gitlab::Utils::StrongMemoize
-  include ExtractsRef
   include Snippets::SendBlob
 
   included do
@@ -19,32 +18,27 @@ module Snippets::BlobsActions
 
   private
 
-  def repository_container
-    snippet
-  end
-
-  # rubocop:disable Gitlab/ModuleWithInstanceVariables
   def blob
-    strong_memoize(:blob) do
-      assign_ref_vars
+    ref_extractor = ExtractsRef::RefExtractor.new(snippet, params.permit(:id, :ref, :path, :ref_type))
+    ref_extractor.extract!
+    return unless ref_extractor.commit
 
-      next unless @commit
-
-      @repo.blob_at(@commit.id, @path)
-    end
+    snippet.repository.blob_at(ref_extractor.commit.id, ref_extractor.path)
   end
-  # rubocop:enable Gitlab/ModuleWithInstanceVariables
+  strong_memoize_attr :blob
 
   def ensure_blob
     render_404 unless blob
+  rescue ExtractsRef::RefExtractor::InvalidPathError
+    render_404
   end
 
   def ensure_repository
-    unless snippet.repo_exists?
-      Gitlab::AppLogger.error(message: "Snippet raw blob attempt with no repo", snippet: snippet.id)
+    return if snippet.repo_exists?
 
-      respond_422
-    end
+    Gitlab::AppLogger.error(message: "Snippet raw blob attempt with no repo", snippet: snippet.id)
+
+    respond_422
   end
 
   def snippet_id
