@@ -4,6 +4,35 @@ class GraphqlController < ApplicationController
   include Gitlab::Auth::AuthFinders
   extend ::Gitlab::Utils::Override
 
+  ERROR_STATUS_MAP = {
+    StandardError => { status: :internal },
+
+    # ApplicationController has similar rescues but we declare these again here because the
+    # `rescue_from StandardError` above would prevent these from bubbling up to ApplicationController.
+    # These also return errors in a JSON format similar to GraphQL errors.
+    ActionController::InvalidAuthenticityToken => { status: :unprocessable_entity },
+
+    # Domain errors -> 422
+    Gitlab::Graphql::Variables::Invalid => { status: :unprocessable_entity },
+    Gitlab::Graphql::Errors::ArgumentError => { status: :unprocessable_entity },
+    Issuables::GroupMembersFilterable::TooManyGroupMembersError => { status: :unprocessable_entity },
+    Issuables::GroupMembersFilterable::TooManyAssignedIssuesError => { status: :unprocessable_entity },
+
+    # Auth errors
+    Gitlab::Auth::RestrictedLanguageServerClientError => { status: :unauthorized },
+    Gitlab::Auth::DpopValidationError => { status: :unauthorized },
+
+    # # Other errors
+    Gitlab::Auth::TooManyIps => { status: :forbidden },
+    RateLimitedService::RateLimitedError => { status: :too_many_requests },
+    Gitlab::Git::ResourceExhaustedError => { status: :service_unavailable },
+    ActiveRecord::QueryAborted => { status: :service_unavailable },
+    ActiveRecord::QueryCanceled => {
+      status: :service_unavailable,
+      custom_message: 'Request timed out. Please try a less complex query or a smaller set of records.'
+    }
+  }.freeze
+
   # Unauthenticated users have access to the API for public data
   skip_before_action :authenticate_user!
   # This is already handled by authorize_access_api!
@@ -40,6 +69,7 @@ class GraphqlController < ApplicationController
   before_action :track_neovim_plugin_usage
   before_action :disable_query_limiting
   before_action :limit_query_size
+  before_action :enforce_language_server_restrictions
 
   before_action :disallow_mutations_for_get
 
@@ -58,6 +88,8 @@ class GraphqlController < ApplicationController
   # SLI. But queries could be multiplexed, so the total duration could be longer.
   urgency :low, [:execute]
 
+  rescue_from(*ERROR_STATUS_MAP.keys, with: :handle_exception)
+
   def execute
     result = if multiplex?
                execute_multiplex
@@ -68,11 +100,7 @@ class GraphqlController < ApplicationController
     render json: result
   end
 
-  rescue_from StandardError do |exception|
-    @exception_object = exception
-
-    log_exception(exception)
-
+  def handle_internal_error(exception)
     if Rails.env.test? || Rails.env.development?
       render_error("Internal server error: #{exception.message}", raised_at: exception.backtrace[0..10].join(' <-- '))
     else
@@ -80,53 +108,6 @@ class GraphqlController < ApplicationController
     end
   end
 
-  rescue_from Gitlab::Auth::DpopValidationError do |exception|
-    log_exception(exception)
-
-    render_error(exception.message, status: :unauthorized)
-  end
-
-  # ApplicationController has similar rescues but we declare these again here because the
-  # `rescue_from StandardError` above would prevent these from bubbling up to ApplicationController.
-  # These also return errors in a JSON format similar to GraphQL errors.
-  rescue_from ActionController::InvalidAuthenticityToken do |exception|
-    render_error(exception.message, status: :unprocessable_entity)
-  end
-
-  rescue_from RateLimitedService::RateLimitedError do |e|
-    e.log_request(request, current_user)
-
-    render_error(e.message, status: :too_many_requests)
-  end
-
-  rescue_from Gitlab::Auth::TooManyIps do |exception|
-    log_exception(exception)
-
-    render_error(exception.message, status: :forbidden)
-  end
-
-  rescue_from Gitlab::Git::ResourceExhaustedError do |exception|
-    log_exception(exception)
-
-    response.headers.merge!(exception.headers)
-    render_error(exception.message, status: :service_unavailable)
-  end
-
-  rescue_from Gitlab::Graphql::Variables::Invalid do |exception|
-    render_error(exception.message, status: :unprocessable_entity)
-  end
-
-  rescue_from Gitlab::Graphql::Errors::ArgumentError do |exception|
-    render_error(exception.message, status: :unprocessable_entity)
-  end
-
-  rescue_from ActiveRecord::QueryAborted do |exception|
-    log_exception(exception)
-
-    error = "Request timed out. Please try a less complex query or a smaller set of records."
-    render_error(error, status: :service_unavailable)
-  end
-
   override :feature_category
   def feature_category
     ::Gitlab::FeatureCategories.default.from_request(request) || super
@@ -134,6 +115,23 @@ class GraphqlController < ApplicationController
 
   private
 
+  def handle_exception(exception)
+    @exception_object = exception
+    http_status = ERROR_STATUS_MAP.dig(exception.class, :status)
+    custom_message = ERROR_STATUS_MAP.dig(exception.class, :custom_message)
+
+    response.headers.merge!(exception.headers) if exception.respond_to?(:headers)
+
+    # For exceptions that support logging of the request
+    exception.try(:log_request, request, current_user)
+
+    log_exception(exception)
+
+    return handle_internal_error(exception) if http_status.nil? || http_status == :internal
+
+    render_error(custom_message || exception.message, status: http_status)
+  end
+
   def check_dpop!
     return unless !!sessionless_user? # DPoP is only enforced on token-based authentication
     return unless current_user && Feature.enabled?(:dpop_authentication, current_user)
@@ -147,6 +145,15 @@ class GraphqlController < ApplicationController
       request: current_request).execute
   end
 
+  def enforce_language_server_restrictions
+    response = Gitlab::Auth::EditorExtensions::LanguageServerClientVerifier.new(
+      current_user: current_user,
+      request: current_request
+    ).execute
+
+    raise Gitlab::Auth::RestrictedLanguageServerClientError, response.message if response.error?
+  end
+
   def permitted_params
     @permitted_params ||= multiplex? ? permitted_multiplex_params : permitted_standalone_query_params
   end
@@ -180,7 +187,7 @@ class GraphqlController < ApplicationController
 
   def any_mutating_query?
     if multiplex?
-      multiplex_queries.any? { |q| mutation?(q[:query], q[:operation_name]) }
+      multiplex_param.any? { |q| mutation?(q[:query], q[:operationName]) }
     else
       mutation?(query)
     end
@@ -279,6 +286,7 @@ class GraphqlController < ApplicationController
     @context ||= {
       current_user: current_user,
       is_sessionless_user: api_user,
+      current_organization: Current.organization,
       request: request,
       scope_validator: ::Gitlab::Auth::ScopeValidator.new(api_user, request_authenticator),
       remove_deprecated: Gitlab::Utils.to_boolean(permitted_params[:remove_deprecated], default: false)
