@@ -7,11 +7,9 @@ class Groups::BoardsController < Groups::ApplicationController
 
   before_action do
     push_frontend_feature_flag(:board_multi_select, group)
-    push_frontend_feature_flag(:realtime_labels, group)
-    experiment(:prominent_create_board_btn, subject: current_user) do |e|
-      e.control {}
-      e.candidate {}
-    end.run
+    push_frontend_feature_flag(:issues_list_drawer, group)
+    push_force_frontend_feature_flag(:work_items_beta, !!group&.work_items_beta_feature_flag_enabled?)
+    push_frontend_feature_flag(:notifications_todos_buttons, current_user)
   end
 
   feature_category :team_planning
@@ -20,16 +18,14 @@ class Groups::BoardsController < Groups::ApplicationController
   private
 
   def board_finder
-    strong_memoize :board_finder do
-      Boards::BoardsFinder.new(parent, current_user, board_id: params[:id])
-    end
+    Boards::BoardsFinder.new(parent, current_user, board_id: params[:id])
   end
+  strong_memoize_attr :board_finder
 
   def board_create_service
-    strong_memoize :board_create_service do
-      Boards::CreateService.new(parent, current_user)
-    end
+    Boards::CreateService.new(parent, current_user)
   end
+  strong_memoize_attr :board_create_service
 
   def authorize_read_board!
     access_denied! unless can?(current_user, :read_issue_board, group)
