@@ -7,11 +7,9 @@ class Projects::BoardsController < Projects::ApplicationController
   before_action :check_issues_available!
   before_action do
     push_frontend_feature_flag(:board_multi_select, project)
-    push_frontend_feature_flag(:realtime_labels, project&.group)
-    experiment(:prominent_create_board_btn, subject: current_user) do |e|
-      e.control {}
-      e.candidate {}
-    end.run
+    push_frontend_feature_flag(:issues_list_drawer, project)
+    push_force_frontend_feature_flag(:work_items_beta, !!project&.work_items_beta_feature_flag_enabled?)
+    push_frontend_feature_flag(:notifications_todos_buttons, current_user)
   end
 
   feature_category :team_planning
