@@ -1,22 +1,17 @@
 # frozen_string_literal: true
 
 class Projects::ClusterAgentsController < Projects::ApplicationController
-  before_action :authorize_can_read_cluster_agent!
+  include KasCookie
 
-  feature_category :kubernetes_management
+  before_action :authorize_read_cluster_agent!
+  before_action :set_kas_cookie, only: [:show], if: -> { current_user }
+
+  feature_category :deployment_management
   urgency :low
 
   def show
     @agent_name = params[:name]
   end
-
-  private
-
-  def authorize_can_read_cluster_agent!
-    return if can?(current_user, :read_cluster, project)
-
-    access_denied!
-  end
 end
 
 Projects::ClusterAgentsController.prepend_mod_with('Projects::ClusterAgentsController')
