@@ -15,7 +15,7 @@ class Projects::JobsController < Projects::ApplicationController
   before_action :authorize_read_build!, except: [:test_report_summary]
   before_action :authorize_read_build_report_results!, only: [:test_report_summary]
   before_action :authorize_update_build!,
-    except: [:index, :show, :viewer, :raw, :trace, :erase, :cancel, :unschedule, :test_report_summary]
+    except: [:index, :show, :viewer, :raw, :trace, :play, :erase, :cancel, :unschedule, :test_report_summary]
   before_action :authorize_cancel_build!, only: [:cancel]
   before_action :authorize_erase_build!, only: [:erase]
   before_action :authorize_use_build_terminal!, only: [:terminal, :terminal_websocket_authorize]
@@ -23,7 +23,6 @@ class Projects::JobsController < Projects::ApplicationController
   before_action :authorize_create_proxy_build!, only: :proxy_websocket_authorize
   before_action :verify_proxy_request!, only: :proxy_websocket_authorize
   before_action :reject_if_build_artifacts_size_refreshing!, only: [:erase]
-  before_action :push_filter_by_name, only: [:index]
   layout 'project'
 
   feature_category :continuous_integration
@@ -33,7 +32,11 @@ class Projects::JobsController < Projects::ApplicationController
 
   def show
     if @build.instance_of?(::Ci::Bridge)
-      redirect_to project_pipeline_path(@build.downstream_pipeline.project, @build.downstream_pipeline.id)
+      if @build.downstream_pipeline&.project
+        redirect_to project_pipeline_path(@build.downstream_pipeline&.project, @build.downstream_pipeline&.id)
+      else
+        redirect_to project_pipeline_path(@build.project, @build.pipeline.id)
+      end
     end
 
     respond_to do |format|
@@ -82,6 +85,8 @@ class Projects::JobsController < Projects::ApplicationController
   end
 
   def retry
+    return access_denied! unless can?(current_user, :retry_job, @build)
+
     Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/424184')
 
     response = Ci::RetryJobService.new(project, current_user).execute(@build)
@@ -98,6 +103,7 @@ class Projects::JobsController < Projects::ApplicationController
   end
 
   def play
+    return access_denied! unless can?(current_user, :play_job, @build)
     return respond_422 unless @build.playable?
 
     job = @build.play(current_user, play_params[:job_variables_attributes])
@@ -123,6 +129,8 @@ class Projects::JobsController < Projects::ApplicationController
   end
 
   def unschedule
+    return access_denied! unless can?(current_user, :unschedule_job, @build)
+
     service_response = Ci::BuildUnscheduleService.new(@build, current_user).execute
 
     if service_response.success?
@@ -293,10 +301,6 @@ class Projects::JobsController < Projects::ApplicationController
 
     ::Gitlab::Workhorse.channel_websocket(service)
   end
-
-  def push_filter_by_name
-    push_frontend_feature_flag(:fe_search_build_by_name, @project)
-  end
 end
 
 Projects::JobsController.prepend_mod_with('Projects::JobsController')
