@@ -8,13 +8,13 @@ class Projects::MergeRequests::ApplicationController < Projects::ApplicationCont
   feature_category :code_review_workflow
 
   before_action do
-    push_force_frontend_feature_flag(:glql_integration, !!project&.glql_integration_feature_flag_enabled?)
     push_force_frontend_feature_flag(:glql_load_on_click, !!project&.glql_load_on_click_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:continue_indented_text, !!project&.continue_indented_text_feature_flag_enabled?)
   end
 
   private
 
+  PIPELINE_DISPLAY_LIMIT = 100
+
   # Normally the methods with `check_(\w+)_available!` pattern are
   # handled by the `method_missing` defined in `ProjectsController::ApplicationController`
   # but that logic does not take the member roles into account, therefore, we handle this
@@ -76,6 +76,7 @@ class Projects::MergeRequests::ApplicationController < Projects::ApplicationCont
   end
 
   def set_pipeline_variables
+    @pipeline_display_limit = PIPELINE_DISPLAY_LIMIT
     @pipelines = Ci::PipelinesForMergeRequestFinder
       .new(@merge_request, current_user)
       .execute
@@ -88,17 +89,15 @@ class Projects::MergeRequests::ApplicationController < Projects::ApplicationCont
     @merge_request.close
   end
 
-  # rubocop: disable CodeReuse/ActiveRecord
   def commit
     commit_id = params[:commit_id].presence
     return unless commit_id
 
-    return unless @merge_request.all_commits.exists?(sha: commit_id) ||
+    return unless @merge_request.commit_exists?(commit_id) ||
       @merge_request.recent_context_commits.map(&:id).include?(commit_id)
 
     @commit ||= @project.commit(commit_id)
   end
-  # rubocop: enable CodeReuse/ActiveRecord
 
   def build_merge_request
     params[:merge_request] ||= ActionController::Parameters.new(source_project: @project)
