@@ -5,12 +5,14 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
   include DiffHelper
   include RendersCommits
   include ProductAnalyticsTracking
+  include Projects::TargetProjects
   include RapidDiffs::Resource
 
   skip_before_action :merge_request
   before_action :authorize_create_merge_request_from!
   before_action :apply_diff_view_cookie!, only: [:diffs, :diff_for_path]
   before_action :build_merge_request, except: [:create]
+  before_action :start_covered_experience_create_mr, only: [:create]
 
   feature_category :continuous_integration, [:pipelines]
 
@@ -112,22 +114,12 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
     render layout: false
   end
 
-  def target_projects
-    render json: ProjectSerializer.new.represent(get_target_projects)
-  end
-
   def diffs_resource(options = {})
     @merge_request&.compare&.diffs(options)
   end
 
   private
 
-  def get_target_projects
-    MergeRequestTargetProjectFinder
-      .new(current_user: current_user, source_project: @project, project_feature: :repository)
-      .execute(include_routes: false, include_fork_networks: true, search: params[:search]).limit(20)
-  end
-
   def define_new_vars
     @noteable = @merge_request
     @target_project = @merge_request.target_project
@@ -194,6 +186,10 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
   def tracking_namespace_source
     @project.namespace
   end
+
+  def start_covered_experience_create_mr
+    Gitlab::CoveredExperience.start_covered_experience_create_merge_request(project)
+  end
 end
 
 Projects::MergeRequests::CreationsController.prepend_mod
