@@ -23,6 +23,7 @@ class Projects::PipelinesController < Projects::ApplicationController
   before_action :authorize_cancel_pipeline!, only: [:cancel]
   before_action :ensure_pipeline, only: [:show, :downloadable_artifacts]
   before_action :reject_if_build_artifacts_size_refreshing!, only: [:destroy]
+  before_action :push_pipelines_graphql_ff, only: [:index]
 
   # Will be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/225596
   before_action :redirect_for_legacy_scope_filter, only: [:index], if: -> { request.format.html? }
@@ -360,6 +361,10 @@ class Projects::PipelinesController < Projects::ApplicationController
   def tracking_project_source
     project
   end
+
+  def push_pipelines_graphql_ff
+    push_frontend_feature_flag(:pipelines_page_graphql, @project)
+  end
 end
 
 Projects::PipelinesController.prepend_mod_with('Projects::PipelinesController')
