@@ -13,11 +13,10 @@ module Projects
       before_action :authorize_update_cicd_settings!, only: :update
       before_action :authorize_reset_cache!, only: :reset_cache
       before_action :check_builds_available!
-      before_action :define_variables
+      before_action :define_variables, only: :show
 
       before_action do
         push_frontend_feature_flag(:ci_variables_pages, current_user)
-        push_frontend_feature_flag(:allow_push_repository_for_job_token, @project)
         push_frontend_ability(ability: :admin_project, resource: @project, user: current_user)
         push_frontend_ability(ability: :admin_protected_environments, resource: @project, user: current_user)
       end
@@ -32,11 +31,13 @@ module Projects
         @variable_limit = ::Plan.default.actual_limits.project_ci_variables
 
         triggers = ::Ci::TriggerSerializer.new.represent(
-          @project.triggers, current_user: current_user, project: @project
+          @project.triggers.with_last_used, current_user: current_user, project: @project
         )
 
         @triggers_json = Gitlab::Json.dump(triggers)
 
+        audit_project_cicd_settings_access
+
         render
       end
 
@@ -101,10 +102,29 @@ module Projects
 
       private
 
+      def audit_project_cicd_settings_access
+        audit_context = {
+          name: 'project_ci_cd_settings_accessed',
+          author: current_user,
+          scope: project,
+          target: project,
+          message: 'User accessed CI/CD settings for project',
+          additional_details: {
+            project_path: project.full_path,
+            project_id: project.id,
+            ip_address: request.remote_ip,
+            timestamp: Time.current.iso8601,
+            action: 'project_ci_cd_settings_page_viewed'
+          }
+        }
+
+        ::Gitlab::Audit::Auditor.audit(audit_context)
+      end
+
       def authorize_reset_cache!
         return if can_any?(current_user, [
           :admin_pipeline,
-          :admin_runner
+          :admin_runners
         ], project)
 
         access_denied!
@@ -114,7 +134,7 @@ module Projects
         return if can_any?(current_user, [
           :admin_cicd_variables,
           :admin_protected_environments,
-          :admin_runner
+          :admin_runners
         ], project)
 
         access_denied!
@@ -142,6 +162,8 @@ module Projects
           :runners_token, :builds_enabled, :build_allow_git_fetch,
           :build_timeout_human_readable, :public_builds, :ci_separated_caches,
           :auto_cancel_pending_pipelines, :ci_config_path, :auto_rollback_enabled,
+          :protect_merge_request_pipelines,
+          :ci_display_pipeline_variables,
           { auto_devops_attributes: [:id, :domain, :enabled, :deploy_strategy],
             ci_cd_settings_attributes: permitted_project_ci_cd_settings_params }
         ].tap do |list|
@@ -179,10 +201,12 @@ module Projects
       end
 
       def define_runners_variables
+        return if Feature.enabled?(:vue_project_runners_settings, @project)
+
         @project_runners = @project.runners.ordered.page(params[:project_page]).per(NUMBER_OF_RUNNERS_PER_PAGE).with_tags
 
         @assignable_runners = current_user
-          .ci_owned_runners
+          .ci_available_runners
           .assignable_for(project)
           .ordered
           .page(params[:specific_page]).per(NUMBER_OF_RUNNERS_PER_PAGE)
@@ -205,7 +229,7 @@ module Projects
       end
 
       def define_triggers_variables
-        @triggers = @project.triggers
+        @triggers = @project.triggers.with_last_used
           .present(current_user: current_user)
 
         @trigger = ::Ci::Trigger.new
