@@ -3,7 +3,7 @@
 class Terraform::ServicesController < ApplicationController
   skip_before_action :authenticate_user!
 
-  feature_category :infrastructure_as_code
+  feature_category :package_registry
 
   def index
     render json: { 'modules.v1' => "/api/#{::API::API.version}/packages/terraform/modules/v1/" }
