@@ -15,7 +15,7 @@ module Mutations
         issue = authorized_find!(project_path: project_path, iid: iid)
         project = issue.project
 
-        ::Issues::UpdateService.new(project: project, current_user: current_user, params: { severity: severity })
+        ::Issues::UpdateService.new(container: project, current_user: current_user, params: { severity: severity })
           .execute(issue)
 
         {
