@@ -6,19 +6,22 @@ module Mutations
       graphql_name 'MergeRequestSetMilestone'
 
       argument :milestone_id,
-               ::Types::GlobalIDType[::Milestone],
-               required: false,
-               loads: Types::MilestoneType,
-               description: <<~DESC
+        ::Types::GlobalIDType[::Milestone],
+        required: false,
+        loads: Types::MilestoneType,
+        description: <<~DESC
                  Milestone to assign to the merge request.
-               DESC
+        DESC
 
       def resolve(project_path:, iid:, milestone: nil)
         merge_request = authorized_find!(project_path: project_path, iid: iid)
         project = merge_request.project
 
-        ::MergeRequests::UpdateService.new(project: project, current_user: current_user, params: { milestone: milestone })
-          .execute(merge_request)
+        ::MergeRequests::UpdateService.new(
+          project: project,
+          current_user: current_user,
+          params: { milestone_id: milestone&.id }
+        ).execute(merge_request)
 
         {
           merge_request: merge_request,
