@@ -3,7 +3,7 @@
 module Types
   module Ci
     # rubocop: disable Graphql/AuthorizeTypes
-    # The permission is presented through `StageType` that has its own authorization
+    # The permission is presented through different types that access JobType
     class JobType < BaseObject
       graphql_name 'CiJob'
 
@@ -84,7 +84,8 @@ module Types
       field :manual_job, GraphQL::Types::Boolean, null: true,
         description: 'Whether the job has a manual action.'
       field :manual_variables, ManualVariableType.connection_type, null: true,
-        description: 'Variables added to a manual job when the job is triggered.'
+        description: 'Variables added to a manual job when the job is triggered.',
+        authorize: :read_manual_variables
       field :play_path, GraphQL::Types::String, null: true,
         description: 'Play path of the job.'
       field :playable, GraphQL::Types::Boolean, null: false, method: :playable?,
@@ -103,6 +104,8 @@ module Types
         description: 'Path to the ref.'
       field :retried, GraphQL::Types::Boolean, null: true,
         description: 'Indicates that the job has been retried.'
+      field :retry_path, GraphQL::Types::String, null: true,
+        description: 'Retry path of the job.'
       field :retryable, GraphQL::Types::Boolean, null: false,
         description: 'Indicates the job can be retried.'
       field :scheduled, GraphQL::Types::Boolean, null: false, method: :scheduled?,
@@ -212,7 +215,7 @@ module Types
           plucked_build_to_runner_manager_ids =
             ::Ci::RunnerManagerBuild.for_build(build_ids).pluck_build_id_and_runner_manager_id
           runner_managers = ::Ci::RunnerManager.id_in(plucked_build_to_runner_manager_ids.values.uniq)
-          Preloaders::RunnerManagerPolicyPreloader.new(runner_managers, current_user).execute
+          ::Ci::Preloaders::RunnerManagerPolicyPreloader.new(runner_managers, current_user).execute
           runner_managers_by_id = runner_managers.index_by(&:id)
 
           build_ids.each do |build_id|
@@ -240,7 +243,13 @@ module Types
       end
 
       def web_path
-        ::Gitlab::Routing.url_helpers.project_job_path(object.project, object)
+        ::Gitlab::Routing.url_helpers.project_job_path(object.project, object) unless object.is_a?(::Ci::Bridge)
+      end
+
+      def retry_path
+        return unless retryable
+
+        ::Gitlab::Routing.url_helpers.retry_project_job_path(object.project, object)
       end
 
       def play_path
@@ -256,10 +265,16 @@ module Types
       end
 
       def manual_variables
-        if object.action? && object.respond_to?(:job_variables)
-          object.job_variables
+        if object.try(:action?) && !object.is_a?(GenericCommitStatus)
+          BatchLoader::GraphQL.for(object.id).batch do |job_ids, loader|
+            variables_by_job_id = ::Ci::JobVariable.for_jobs(job_ids).group_by(&:job_id)
+
+            job_ids.each do |id|
+              loader.call(id, variables_by_job_id[id] || [])
+            end
+          end
         else
-          []
+          ::Ci::JobVariable.none
         end
       end
 
