@@ -52,13 +52,19 @@ module Types
         description: 'Size (in bytes) of the blob, or the blob target if stored externally.'
 
       field :raw_blob, GraphQL::Types::String, null: true, method: :data,
-        description: 'Raw content of the blob.'
+        description: 'Raw content of the blob.',
+        calls_gitaly: true,
+        complexity: 25
 
       field :base64_encoded_blob, GraphQL::Types::String, null: true,
-        experiment: { milestone: '17.1' }, description: 'Content of blob is encoded base64. Returns `null` if the `unicode_escaped_data` feature flag is disabled.'
+        experiment: { milestone: '17.1' }, description: 'Content of blob is encoded base64. Returns `null` if the `unicode_escaped_data` feature flag is disabled.',
+        calls_gitaly: true,
+        complexity: 25
 
       field :raw_text_blob, GraphQL::Types::String, null: true, method: :text_only_data,
-        description: 'Raw content of the blob, if the blob is text data.'
+        description: 'Raw content of the blob, if the blob is text data.',
+        calls_gitaly: true,
+        complexity: 25
 
       field :stored_externally, GraphQL::Types::Boolean, null: true, method: :stored_externally?,
         description: "Whether the blob's content is stored externally (for instance, in LFS)."
@@ -122,7 +128,8 @@ module Types
       field :plain_data, GraphQL::Types::String,
         description: 'Blob plain highlighted data.',
         null: true,
-        calls_gitaly: true
+        calls_gitaly: true,
+        complexity: 150
 
       field :can_modify_blob, GraphQL::Types::Boolean, null: true, method: :can_modify_blob?,
         calls_gitaly: true,
