@@ -27,10 +27,12 @@ module Types
     field :username,
       type: GraphQL::Types::String,
       null: false,
+      scopes: [:api, :read_api, :ai_workflows],
       description: 'Username of the user. Unique within the instance of GitLab.'
     field :name,
       type: GraphQL::Types::String,
       null: false,
+      scopes: [:api, :read_api, :ai_workflows],
       resolver_method: :redacted_name,
       description: 'Human-readable name of the user. ' \
         'Returns `****` if the user is a project bot and the requester does not have permission to view the project.'
@@ -88,6 +90,9 @@ module Types
     field :group_count,
       resolver: Resolvers::Users::GroupCountResolver,
       description: 'Group count for the user.'
+    field :project_count,
+      resolver: Resolvers::Users::ProjectCountResolver,
+      description: 'Project count for the user.'
     field :status,
       type: Types::UserStatusType,
       null: true,
@@ -109,7 +114,8 @@ module Types
     field :namespace,
       type: Types::NamespaceType,
       null: true,
-      description: 'Personal namespace of the user.'
+      description: 'Personal namespace of the user.',
+      resolver_method: :resolve_user_namespace
 
     field :todos,
       Types::TodoType.connection_type,
@@ -134,6 +140,10 @@ module Types
       Types::UserCalloutType.connection_type,
       null: true,
       description: 'User callouts that belong to the user.'
+    field :group_callouts,
+      Types::Users::GroupCalloutType.connection_type,
+      null: true,
+      description: 'User callouts that belong to the user per group.'
     field :timelogs,
       Types::TimelogType.connection_type,
       null: true,
@@ -207,10 +217,16 @@ module Types
       null: true,
       description: 'Discord ID of the user.'
 
+    field :github,
+      type: ::GraphQL::Types::String,
+      null: true,
+      description: 'GitHub profile name of the user.'
+
     field :organization,
       type: ::GraphQL::Types::String,
       null: true,
-      description: 'Who the user represents or works for.'
+      description: 'Who the user represents or works for.',
+      method: :user_detail_organization
 
     field :job_title,
       type: ::GraphQL::Types::String,
@@ -255,5 +271,11 @@ module Types
     def redacted_name
       object.redacted_name(context[:current_user])
     end
+
+    def resolve_user_namespace
+      return object.namespace if object.namespace&.organization_id == context[:current_organization].id
+
+      nil
+    end
   end
 end
