@@ -131,12 +131,22 @@ module ApplicationHelper
     sanitize(str, tags: %w[a span])
   end
 
+  def project_studio_available?
+    Users::ProjectStudio.new(current_user).available?
+  end
+
+  def project_studio_enabled?
+    Users::ProjectStudio.new(current_user).enabled?
+  end
+
   def body_data
     {
       page: body_data_page,
       page_type_id: controller.params[:id],
       group: @group&.path,
-      group_full_path: @group&.full_path
+      group_full_path: @group&.full_path,
+      project_studio_available: project_studio_available?.to_s,
+      project_studio_enabled: project_studio_enabled?.to_s
     }.merge(project_data)
   end
 
@@ -224,16 +234,6 @@ module ApplicationHelper
     end
   end
 
-  # This needs to be used outside of Rails
-  def self.promo_host
-    'about.gitlab.com'
-  end
-
-  # Convenient method for Rails helper
-  def promo_host
-    ApplicationHelper.promo_host
-  end
-
   # This needs to be used outside of Rails
   def self.community_forum
     'https://forum.gitlab.com'
@@ -244,16 +244,8 @@ module ApplicationHelper
     ApplicationHelper.community_forum
   end
 
-  def self.promo_url
-    "https://#{promo_host}"
-  end
-
-  def promo_url
-    ApplicationHelper.promo_url
-  end
-
   def support_url
-    Gitlab::CurrentSettings.current_application_settings.help_page_support_url.presence || "#{promo_url}/get-help/"
+    Gitlab::CurrentSettings.current_application_settings.help_page_support_url.presence || promo_url(path: '/get-help/')
   end
 
   def instance_review_permitted?
@@ -325,7 +317,10 @@ module ApplicationHelper
     class_names << 'issue-boards-page gl-overflow-auto' if current_controller?(:boards)
     class_names << 'epic-boards-page gl-overflow-auto' if current_controller?(:epic_boards)
     class_names << 'with-performance-bar' if performance_bar_enabled?
-    class_names << 'with-header' if @with_header || !current_user
+    class_names << 'with-header' if @with_header || !current_user || project_studio_enabled?
+    class_names << 'application-chrome' if project_studio_enabled?
+    class_names << 'page-with-panels' if project_studio_enabled?
+    class_names << 'with-gl-container-queries' if project_studio_enabled?
     class_names << system_message_class
 
     class_names
@@ -337,6 +332,7 @@ module ApplicationHelper
 
   def body_scroll_classes
     return '' if content_for(:disable_fixed_body_scroll).present?
+    return '' if project_studio_enabled?
 
     # Custom class is used instead of Tailwind so people can discover this, do not replace this with Tailwind analog
     'body-fixed-scrollbar'
@@ -396,6 +392,12 @@ module ApplicationHelper
     external_redirect_path(url: "https://bsky.app/profile/#{user.bluesky}")
   end
 
+  def orcid_url(user)
+    return '' if user.orcid.blank?
+
+    external_redirect_path(url: "https://orcid.org/#{user.orcid}")
+  end
+
   def mastodon_url(user)
     return '' if user.mastodon.blank?
 
@@ -408,6 +410,12 @@ module ApplicationHelper
     end
   end
 
+  def github_url(user)
+    return '' if user.github.blank?
+
+    "https://github.com/#{user.github}"
+  end
+
   def collapsed_super_sidebar?
     return false if @force_desktop_expanded_sidebar
 
@@ -472,15 +480,19 @@ module ApplicationHelper
       {
         members: members_group_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id]),
         issues: issues_group_autocomplete_sources_path(object),
+        issuesAlternative: issues_group_autocomplete_sources_path(object),
+        workItems: issues_group_autocomplete_sources_path(object),
         mergeRequests: merge_requests_group_autocomplete_sources_path(object),
         labels: labels_group_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id]),
         milestones: milestones_group_autocomplete_sources_path(object),
         commands: commands_group_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id])
-      }
+      }.compact
     else
       {
         members: members_project_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id]),
         issues: issues_project_autocomplete_sources_path(object),
+        issuesAlternative: issues_project_autocomplete_sources_path(object),
+        workItems: issues_project_autocomplete_sources_path(object),
         mergeRequests: merge_requests_project_autocomplete_sources_path(object),
         labels: labels_project_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id]),
         milestones: milestones_project_autocomplete_sources_path(object),
@@ -488,7 +500,7 @@ module ApplicationHelper
         snippets: snippets_project_autocomplete_sources_path(object),
         contacts: contacts_project_autocomplete_sources_path(object, type: noteable_type, type_id: params[:id]),
         wikis: object.feature_available?(:wiki, current_user) ? wikis_project_autocomplete_sources_path(object) : nil
-      }
+      }.compact
     end
   end
 
@@ -528,6 +540,10 @@ module ApplicationHelper
     end
   end
 
+  def ai_panel_expanded?
+    cookies[:ai_panel_active_tab].present?
+  end
+
   private
 
   def browser_id
