@@ -186,6 +186,15 @@ module AuthHelper
       end
   end
 
+  def step_up_auth_documentation_link(flow)
+    link_url = flow.documentation_link
+
+    return unless link_url
+
+    provider_label = ::Gitlab::Auth::OAuth::Provider.label_for(flow.provider)
+    link_to(provider_label, link_url, target: '_blank', rel: 'noopener noreferrer', class: 'gl-link')
+  end
+
   def provider_image_tag(provider, size = 64)
     label = label_for_provider(provider)
 
@@ -220,14 +229,15 @@ module AuthHelper
     current_user.allow_password_authentication_for_web? && !current_user.password_automatically_set?
   end
 
-  def auth_app_owner_text(owner)
-    return _('An administrator added this OAuth application ') unless owner
+  def auth_app_owner_text(application)
+    return _('An anonymous service added this dynamically created OAuth application ') if application.dynamic?
+    return _('An administrator added this OAuth application ') unless application.owner
 
-    if owner.is_a?(Group)
-      group_link = link_to(owner.name, group_path(owner))
+    if application.owner.is_a?(Group)
+      group_link = link_to(application.owner.name, group_path(application.owner))
       safe_format(_("%{group_link} added this OAuth application "), group_link: group_link)
     else
-      user_link = link_to(owner.name, user_path(owner))
+      user_link = link_to(application.owner.name, user_path(application.owner))
       safe_format(_("%{user_link} added this OAuth application "), user_link: user_link)
     end
   end
@@ -241,11 +251,27 @@ module AuthHelper
               end
 
     { button_text: _('Delete one-time password authenticator'),
+      icon: 'remove',
       message: message,
       path: destroy_otp_profile_two_factor_auth_path,
       password_required: password_required.to_s }
   end
 
+  def delete_passkey_data(password_required, path)
+    message = if password_required
+                s_('ProfilesAuthentication|Are you sure you want to delete this passkey? ' \
+                  'Enter your password to continue.')
+              else
+                s_('ProfilesAuthentication|Are you sure you want to delete this passkey?')
+              end
+
+    { button_text: s_('ProfilesAuthentication|Delete passkey'),
+      icon: 'remove',
+      message: message,
+      path: path,
+      password_required: password_required.to_s }
+  end
+
   def delete_webauthn_device_data(password_required, path)
     message = if password_required
                 _('Are you sure you want to delete this WebAuthn device? ' \
@@ -269,7 +295,7 @@ module AuthHelper
                 _('Are you sure you want to invalidate your one-time password authenticator and WebAuthn devices?')
               end
 
-    { button_text: _('Disable two-factor authentication'),
+    { button_text: _('Disable 2FA'),
       message: message,
       path: profile_two_factor_auth_path,
       password_required: password_required.to_s }
@@ -288,6 +314,7 @@ module AuthHelper
       method: 'post',
       path: codes_profile_two_factor_auth_path,
       password_required: password_required.to_s,
+      size: 'small',
       variant: 'default' }
   end
 
