@@ -79,7 +79,9 @@ module Ci
 
       content_tag(content_tag_variant, href: path, class: badge_classes, title: title, data: data) do
         if show_status_text
-          content_tag(:span, ci_icon_for_status(status), { class: icon_wrapper_class }) + content_tag(:span, status.label, { class: 'gl-mx-2 gl-whitespace-nowrap gl-leading-1 gl-self-center', data: { testid: 'ci-icon-text' } })
+          content_tag(:span, ci_icon_for_status(status),
+            { class: icon_wrapper_class }) + content_tag(:span, status.label,
+              { class: 'gl-mx-2 gl-whitespace-nowrap gl-leading-1 gl-self-center', data: { testid: 'ci-icon-text' } })
         else
           content_tag(:span, ci_icon_for_status(status), { class: icon_wrapper_class })
         end
