@@ -15,22 +15,12 @@ module ExploreHelper
       namespace_id: params[:namespace_id]
     }
 
+    exist_opts[:language] = params[:language]
+
     options = exist_opts.merge(options).delete_if { |key, value| value.blank? }
     request_path_with_options(options)
   end
 
-  def filter_groups_path(options = {})
-    request_path_with_options(options)
-  end
-
-  def explore_nav_links
-    @explore_nav_links ||= get_explore_nav_links
-  end
-
-  def explore_nav_link?(link)
-    explore_nav_links.include?(link)
-  end
-
   def public_visibility_restricted?
     Gitlab::VisibilityLevel.public_visibility_restricted?
   end
@@ -54,10 +44,6 @@ module ExploreHelper
 
   private
 
-  def get_explore_nav_links
-    [:projects, :groups, :snippets]
-  end
-
   def request_path_with_options(options = {})
     request.path + "?#{options.to_param}"
   end
