@@ -151,20 +151,6 @@ module MergeRequestsHelper
     end
   end
 
-  def user_merge_requests_counts
-    @user_merge_requests_counts ||= begin
-      assigned_count = assigned_issuables_count(:merge_requests)
-      review_requested_count = review_requested_merge_requests_count
-      total_count = assigned_count + review_requested_count
-
-      {
-        assigned: assigned_count,
-        review_requested: review_requested_count,
-        total: total_count
-      }
-    end
-  end
-
   def reviewers_label(merge_request, include_value: true)
     reviewers = merge_request.reviewers
 
@@ -258,6 +244,8 @@ module MergeRequestsHelper
   def common_merge_request_list_data(current_user)
     {
       autocomplete_award_emojis_path: autocomplete_award_emojis_path,
+      merge_request_target_branches_path: autocomplete_merge_request_target_branches_path,
+      merge_request_source_branches_path: autocomplete_merge_request_source_branches_path,
       initial_sort: default_merge_request_sort || current_user&.user_preference&.merge_requests_sort,
       is_public_visibility_restricted:
         Gitlab::CurrentSettings.restricted_visibility_levels&.include?(Gitlab::VisibilityLevel::PUBLIC).to_s,
@@ -276,6 +264,7 @@ module MergeRequestsHelper
     merge_project = merge_request_source_project_for_project(project)
 
     common_merge_request_list_data(current_user).merge({
+      namespace_id: project.id,
       full_path: project.full_path,
       has_any_merge_requests: project_merge_requests(project).exists?.to_s,
       new_merge_request_path: merge_project && project_new_merge_request_path(merge_project),
@@ -291,7 +280,7 @@ module MergeRequestsHelper
 
   def group_merge_requests_list_data(group, current_user)
     common_merge_request_list_data(current_user).merge({
-      group_id: group.id,
+      namespace_id: group.id,
       full_path: group.full_path,
       show_new_resource_dropdown: (current_user.presence && any_projects?(@projects)).to_s,
       has_any_merge_requests: group_merge_requests(group).exists?.to_s,
@@ -306,13 +295,10 @@ module MergeRequestsHelper
     { identity_verification_required: 'false' }
   end
 
-  def merge_request_dashboard_enabled?(current_user)
-    current_user.merge_request_dashboard_enabled?
-  end
-
   def sticky_header_data(project, merge_request)
     data = {
       iid: merge_request.iid,
+      canResolveDiscussion: merge_request.resolvable_discussions.first&.can_resolve_discussion?(current_user).to_s,
       defaultBranchName: project.default_branch,
       projectPath: project.full_path,
       sourceProjectPath: merge_request.source_project_path,
@@ -320,6 +306,7 @@ module MergeRequestsHelper
       isFluidLayout: fluid_layout.to_s,
       blocksMerge: project.only_allow_merge_if_all_discussions_are_resolved?.to_s,
       imported: merge_request.imported?.to_s,
+      isDraft: merge_request.draft.to_s,
       tabs: [
         [
           'show',
@@ -349,7 +336,6 @@ module MergeRequestsHelper
 
   def show_mr_dashboard_banner?
     request.query_string.present? &&
-      merge_request_dashboard_enabled?(current_user) &&
       current_page?(merge_requests_search_dashboard_path) &&
       show_new_mr_dashboard_banner?
   end
@@ -358,12 +344,14 @@ module MergeRequestsHelper
     merge_request.persisted? ? merge_request.squash : merge_request.squash_enabled_by_default?
   end
 
-  private
+  def merge_request_dashboard_show_drafts?
+    return true if Feature.disabled?(:mr_dashboard_drafts_toggle, current_user)
 
-  def review_requested_merge_requests_count
-    current_user.review_requested_open_merge_requests_count
+    current_user.merge_request_dashboard_show_drafts
   end
 
+  private
+
   def default_suggestion_commit_message(project)
     project.suggestion_commit_message.presence || Gitlab::Suggestions::CommitMessage::DEFAULT_SUGGESTION_COMMIT_MESSAGE
   end
@@ -406,15 +394,15 @@ module MergeRequestsHelper
     link_to branch,
       branch_path,
       title: branch_title,
-      class: 'ref-container gl-inline-block gl-truncate gl-max-w-26 gl-ml-2'
+      class: 'ref-container gl-inline-block gl-truncate gl-max-w-26 gl-ml-2 gl-shrink-0'
   end
 
   def merge_request_header(merge_request)
     link_to_author = link_to_member(merge_request.author, size: 24, extra_class: 'gl-font-bold gl-mr-2', avatar: false)
-    target_branch_class = "ref-container gl-inline-block gl-truncate gl-max-w-26"
+    target_branch_class = "ref-container gl-inline-block gl-truncate gl-max-w-26 gl-shrink-0"
     copy_action_description = _('Copy branch name')
     copy_action_shortcut = 'b'
-    copy_button_title = "#{copy_action_description} <kbd class='flat ml-1' " \
+    copy_button_title = "#{copy_action_description} <kbd class='flat gl-ml-2' " \
       "aria-hidden=true>#{copy_action_shortcut}</kbd>"
 
     target_branch_class = if @project.default_branch != merge_request.target_branch
@@ -428,14 +416,14 @@ module MergeRequestsHelper
       title: copy_button_title,
       aria_keyshortcuts: copy_action_shortcut,
       aria_label: copy_action_description,
-      class: '!gl-hidden md:!gl-inline-block gl-mx-1 js-source-branch-copy'
+      class: '!gl-hidden @md/panel:!gl-inline-block gl-mx-1 js-source-branch-copy'
     )
 
     target_copy_button = clipboard_button(
       text: merge_request.target_branch,
       title: copy_action_description,
       aria_label: copy_action_description,
-      class: '!gl-hidden md:!gl-inline-block gl-mx-1'
+      class: '!gl-hidden @md/panel:!gl-inline-block gl-mx-1'
     )
 
     target_branch = link_to merge_request.target_branch,
@@ -449,7 +437,9 @@ module MergeRequestsHelper
       copy_button: copy_button.html_safe,
       target_branch: target_branch.html_safe,
       target_copy_button: " ",
-      created_at: time_ago_with_tooltip(merge_request.created_at, html_class: 'gl-inline-block').html_safe
+      created_at: time_ago_with_tooltip(merge_request.created_at, html_class: 'gl-inline-block').html_safe,
+      author_container_start: '<div class="merge-request-author-container">'.html_safe,
+      author_container_end: '</div>'.html_safe
     }
 
     if @project.default_branch != merge_request.target_branch
@@ -457,7 +447,7 @@ module MergeRequestsHelper
     end
 
     safe_format(_(
-      '%{author} requested to merge %{source_branch} %{copy_button} ' \
+      '%{author_container_start}%{author}requested to merge %{author_container_end}%{source_branch} %{copy_button} ' \
         'into %{target_branch} %{target_copy_button} %{created_at}'
     ), copy_button_data)
   end
@@ -477,9 +467,6 @@ module MergeRequestsHelper
   end
 
   def merge_request_dashboard_role_based_data
-    is_author_or_assignee = ::Feature.enabled?(:merge_request_dashboard_author_or_assignee, current_user,
-      type: :gitlab_com_derisk)
-
     {
       tabs: [
         {
@@ -489,7 +476,7 @@ module MergeRequestsHelper
             [
               {
                 id: 'reviews',
-                title: _('Reviewer (Active)'),
+                title: _('Review requested'),
                 helpContent: _('Merge requests awaiting your review.'),
                 query: 'reviewRequestedMergeRequests',
                 variables: {
@@ -497,9 +484,19 @@ module MergeRequestsHelper
                   perPage: 10
                 }
               },
+              {
+                id: 'assigned',
+                title: _('Your merge requests'),
+                helpContent: _("Your merge requests"),
+                query: 'authorOrAssigneeMergeRequests',
+                variables: {
+                  draft: merge_request_dashboard_show_drafts?,
+                  perPage: 10
+                }
+              },
               {
                 id: 'reviews_inactive',
-                title: _('Reviewer (Inactive)'),
+                title: _('Reviewed'),
                 hideCount: true,
                 helpContent: _("Merge requests you've reviewed."),
                 query: 'reviewRequestedMergeRequests',
@@ -507,40 +504,6 @@ module MergeRequestsHelper
                   reviewStates: %w[APPROVED REQUESTED_CHANGES REVIEWED],
                   perPage: 10
                 }
-              },
-              {
-                id: 'assigned',
-                title: _('Your merge requests (Active)'),
-                helpContent: _(
-                  "Your merge requests that need reviewers assigned, " \
-                    "or has feedback to address."
-                ),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
-                variables: {
-                  or: {
-                    reviewerWildcard: 'NONE',
-                    reviewStates: %w[REQUESTED_CHANGES REVIEWED]
-                  },
-                  perPage: 10
-                }
-              },
-              {
-                id: 'assigned_inactive',
-                title: _('Your merge requests (Inactive)'),
-                hideCount: true,
-                helpContent: _(
-                  "Your merge requests awaiting approvals, " \
-                    "or has been approved by all assigned reviewers."
-                ),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
-                variables: {
-                  reviewStates: %w[APPROVED UNAPPROVED UNREVIEWED REVIEW_STARTED],
-                  not: {
-                    reviewStates: %w[REQUESTED_CHANGES REVIEWED]
-                  },
-                  ignoredReviewerUsername: ::Users::Internal.duo_code_review_bot.username,
-                  perPage: 10
-                }
               }
             ]
           ]
@@ -565,7 +528,7 @@ module MergeRequestsHelper
                 id: 'merged_recently_assigned',
                 title: _('Assigned'),
                 helpContent: _('Your merge requests that have been merged.'),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
                   state: 'merged',
                   mergedAfter: 2.weeks.ago.to_time.iso8601,
@@ -580,13 +543,7 @@ module MergeRequestsHelper
   end
 
   def merge_request_dashboard_data
-    is_author_or_assignee = ::Feature.enabled?(:merge_request_dashboard_author_or_assignee, current_user,
-      type: :gitlab_com_derisk)
-
-    if Feature.enabled?(:mr_dashboard_list_type_toggle, current_user, type: :beta) &&
-        current_user.merge_request_dashboard_list_type == 'role_based'
-      return merge_request_dashboard_role_based_data
-    end
+    return merge_request_dashboard_role_based_data if current_user.user_preference.role_based?
 
     {
       tabs: [
@@ -599,10 +556,10 @@ module MergeRequestsHelper
                 id: 'returned_to_you',
                 title: _('Returned to you'),
                 helpContent: _('Reviewers left feedback, or requested changes from you, on these merge requests.'),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
                   reviewStates: %w[REVIEWED REQUESTED_CHANGES],
-                  ignoredReviewerUsername: ::Users::Internal.duo_code_review_bot.username
+                  ignoredReviewerUsername: duo_code_review_bot.username
                 }
               },
               {
@@ -616,20 +573,14 @@ module MergeRequestsHelper
               },
               {
                 id: 'assigned_to_you',
-                title: is_author_or_assignee ? _('Your merge requests') : _('Assigned to you'),
-
-                helpContent: if is_author_or_assignee
-                               _("Merge requests you authored or are assigned to, " \
-                                 "without reviewers.")
-                             else
-                               _("You're assigned to these merge requests, but they don't have reviewers yet.")
-                             end,
-
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
+                title: _('Your merge requests'),
+                helpContent: _("Merge requests you authored or are assigned to, without reviewers."),
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
+                  draft: merge_request_dashboard_show_drafts?,
                   or: {
                     reviewerWildcard: 'NONE',
-                    onlyReviewerUsername: ::Users::Internal.duo_code_review_bot.username
+                    onlyReviewerUsername: duo_code_review_bot.username
                   }
                 }
               }
@@ -637,7 +588,7 @@ module MergeRequestsHelper
             [
               {
                 id: 'waiting_for_assignee',
-                title: is_author_or_assignee ? _('Waiting for author or assignee') : _('Waiting for assignee'),
+                title: _('Waiting for author or assignee'),
                 hideCount: true,
                 helpContent: _(
                   "Your reviews you've requested changes for " \
@@ -653,9 +604,9 @@ module MergeRequestsHelper
                 title: _('Waiting for approvals'),
                 hideCount: true,
                 helpContent: _('Your merge requests that are waiting for approvals.'),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
-                  ignoredReviewerUsername: ::Users::Internal.duo_code_review_bot.username,
+                  ignoredReviewerUsername: duo_code_review_bot.username,
                   reviewStates: %w[UNREVIEWED UNAPPROVED REVIEW_STARTED],
                   not: {
                     reviewStates: %w[REQUESTED_CHANGES REVIEWED]
@@ -677,9 +628,9 @@ module MergeRequestsHelper
                 title: _('Approved by others'),
                 hideCount: true,
                 helpContent: _('Your merge requests with approvals by all assigned reviewers.'),
-                query: is_author_or_assignee ? 'authorOrAssigneeMergeRequests' : 'assignedMergeRequests',
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
-                  ignoredReviewerUsername: ::Users::Internal.duo_code_review_bot.username,
+                  ignoredReviewerUsername: duo_code_review_bot.username,
                   reviewState: 'APPROVED',
                   not: {
                     reviewStates: %w[REQUESTED_CHANGES REVIEWED UNREVIEWED REVIEW_STARTED UNAPPROVED]
@@ -711,6 +662,19 @@ module MergeRequestsHelper
       ]
     }
   end
+
+  def dashboard_list_title(list_id)
+    merge_request_dashboard_data[:tabs]
+      .flat_map { |tab| tab[:lists] }
+      .flatten
+      .find { |list| list[:id] == list_id }
+      &.dig(:title) || ''
+  end
+
+  def duo_code_review_bot
+    ::Users::Internal.duo_code_review_bot
+  end
+  strong_memoize_attr :duo_code_review_bot
 end
 
 MergeRequestsHelper.prepend_mod_with('MergeRequestsHelper')
