@@ -61,7 +61,7 @@ module Nav
           ::Gitlab::Nav::TopNavMenuItem.build(
             id: 'new_group_work_item',
             title: _('New work item'),
-            component: 'create_new_group_work_item_modal',
+            component: 'create_new_work_item_modal',
             data: {
               track_action: 'click_link_new_group_work_item',
               track_label: 'plus_menu_dropdown',
@@ -109,6 +109,7 @@ module Nav
               id: 'new_issue',
               title: _('New issue'),
               href: new_project_issue_path(project),
+              component: 'create_new_work_item_modal',
               data: {
                 track_action: 'click_link_new_issue',
                 track_label: 'plus_menu_dropdown',
@@ -150,7 +151,7 @@ module Nav
         )
       end
 
-      if can_admin_project_member?(project)
+      if can?(current_user, :invite_member, project)
         menu_items.push(invite_members_menu_item(partial: 'projects/invite_members_top_nav_link'))
       end
 
@@ -195,8 +196,8 @@ module Nav
         )
       end
 
-      if Feature.enabled?(:ui_for_organizations, current_user) &&
-          Feature.enabled?(:allow_organization_creation, current_user) &&
+      if Feature.enabled?(:organization_switching, current_user) &&
+          ui_for_organizations_enabled? &&
           current_user.can?(:create_organization)
         menu_items.push(
           ::Gitlab::Nav::TopNavMenuItem.build(
