@@ -8,15 +8,6 @@ module ViteHelper
     Gitlab::Utils.to_boolean(ViteRuby.env['VITE_ENABLED'], default: false)
   end
 
-  def vite_origin
-    ViteRuby.config.origin
-  end
-
-  def vite_hmr_ws_origin
-    protocol = ViteRuby.config.https ? 'wss' : 'ws'
-    "#{protocol}://#{ViteRuby.config.host_with_port}"
-  end
-
   def vite_page_entrypoint_paths(custom_action_name = nil)
     action_name = custom_action_name || controller.action_name
     action = case action_name
@@ -29,6 +20,17 @@ module ViteHelper
 
     parts.map
          .with_index { |part, idx| "pages.#{(parts[0, idx] << part).join('.')}.js" }
+          .filter do |name|
+            # always truthy in dev mode for non-existing entrypoints
+            # we return /* doesn't exist */ on the dev server for such false positives
+            ViteRuby.instance.manifest.path_for(name)
+          rescue ViteRuby::MissingEntrypointError
+            # we don't know if an entrypoint exists for each of the controller action part
+            # for example: it might be present for the last part but not for the first part
+            #   - pages.merge_requests.js -> empty, error thrown
+            #   - pages.merge_requests.edit.js -> found
+            false
+          end
   end
 
   def universal_stylesheet_link_tag(path, **options)
@@ -36,15 +38,20 @@ module ViteHelper
 
     options[:extname] = false
 
-    stylesheet_link_tag(
-      ViteRuby.instance.manifest.path_for("stylesheets/styles.#{path}.scss", type: :stylesheet),
-      **options
-    )
+    vite_stylesheet_tag(css_entrypoint_name(path), **options)
   end
 
   def universal_path_to_stylesheet(path, **options)
     return ActionController::Base.helpers.stylesheet_path(path, **options) unless vite_enabled?
 
-    ViteRuby.instance.manifest.path_for("stylesheets/styles.#{path}.scss", **options)
+    ViteRuby.instance.manifest.path_for(css_entrypoint_name(path), **options)
+  end
+
+  private
+
+  # we must add `styles/` because ViteRuby prepends assets folder to the request if `/` is missing
+  # we must use `.css` extension, otherwise Vite will not detect this as a CSS entrypoint
+  def css_entrypoint_name(path)
+    "styles/#{path}.css"
   end
 end
