@@ -7,17 +7,11 @@ module X509Helper
     subjects = {}
 
     Net::LDAP::DN.new(subject).each_pair do |key, value|
-      if key.upcase.start_with?(*search_keys.map(&:upcase))
-        subjects[key.upcase] = value
-      end
+      subjects[key.upcase] = value if key.upcase.start_with?(*search_keys.map(&:upcase))
     end
 
     subjects
   rescue StandardError
     {}
   end
-
-  def x509_signature?(sig)
-    sig.is_a?(CommitSignatures::X509CommitSignature) || sig.is_a?(Gitlab::X509::Signature)
-  end
 end
