@@ -4,10 +4,9 @@ class AuthenticationEvent < ApplicationRecord
   include UsageStatistics
 
   TWO_FACTOR = 'two-factor'
-  TWO_FACTOR_U2F = 'two-factor-via-u2f-device'
   TWO_FACTOR_WEBAUTHN = 'two-factor-via-webauthn-device'
   STANDARD = 'standard'
-  STATIC_PROVIDERS = [TWO_FACTOR, TWO_FACTOR_U2F, TWO_FACTOR_WEBAUTHN, STANDARD].freeze
+  STATIC_PROVIDERS = [TWO_FACTOR, TWO_FACTOR_WEBAUTHN, STANDARD].freeze
 
   belongs_to :user, optional: true
 
