@@ -41,6 +41,16 @@ module TokenAuthenticatable
         end
       end
 
+      define_singleton_method("encode") do |token|
+        strategy.encode(token)
+      end
+
+      if options[:encrypted] && respond_to?(:scope)
+        scope :with_encrypted_tokens, ->(token_values) do
+          where("#{token_field}_encrypted" => Array.wrap(token_values))
+        end
+      end
+
       mod = token_authenticatable_module
 
       mod.define_method(token_field) do
@@ -65,6 +75,10 @@ module TokenAuthenticatable
         strategy.reset_token!(self)
       end
 
+      mod.define_method("rewrite_#{token_field}") do
+        strategy.write_new_token(self)
+      end
+
       mod.define_method("#{token_field}_matches?") do |other_token|
         token = read_attribute(token_field)
         token.present? && ActiveSupport::SecurityUtils.secure_compare(other_token, token)
