@@ -210,8 +210,14 @@ class ContainerRepository < ApplicationRecord
   end
 
   def has_tags?
-    tags.any?
+    if gitlab_api_client.supports_gitlab_api?
+      page = tags_page(page_size: 1) # Fetch one tag to check existence
+      page[:tags].present?
+    else
+      manifest&.dig('tags').present?
+    end
   end
+  strong_memoize_attr :has_tags?
 
   def root_repository?
     name.empty?
@@ -309,16 +315,18 @@ class ContainerRepository < ApplicationRecord
     self.find_by(project: path.repository_project, name: path.repository_name)
   end
 
-  def has_protected_tag_rules_for_delete?(user)
-    return true if user.nil?
+  def protected_from_delete_by_tag_rules?(user)
+    return true unless user
+
+    # Admins are not restricted by mutable tag protection rules
     return false if user.can_admin_all_resources?
 
+    # Check for mutable tag protection rules
     return false unless project.has_container_registry_protected_tag_rules?(
       action: 'delete',
       access_level: project.team.max_member_access(user.id)
     )
 
-    # This is an API call so we put it last
     return false unless has_tags?
 
     true
