@@ -137,21 +137,31 @@ class ProjectTeam
       !member.invite? && target_user_ids.include?(member.user_id)
     end
 
-    source_members.map! do |member|
+    new_members = source_members.map do |member|
       new_member = member.dup
       new_member.id = nil
       new_member.source = target_project
       # So that a maintainer cannot import a member with owner access
       new_member.access_level = [new_member.access_level, importer_access_level].min
       new_member.created_by = current_user
+
+      params = { access_level: new_member.access_level, member_role_id: member.member_role_id }
+      if new_member.prevent_role_assignement?(current_user, params)
+        new_member.errors.add(:base, _("Insufficient permissions to assign this member"))
+      end
+
       new_member
     end
 
     ProjectMember.transaction do
-      source_members.each(&:save)
+      new_members.each do |member|
+        next if member.errors.any?
+
+        member.save
+      end
     end
 
-    source_members
+    new_members
   rescue StandardError
     false
   end
@@ -223,6 +233,26 @@ class ProjectTeam
     max_member_access_for_user_ids([user_id])[user_id]
   end
 
+  # Return the highest access level for a user
+  #
+  # A special case is handled here when the user is a GitLab admin
+  # which implies it has "OWNER" access everywhere, but should not
+  # officially appear as a member of a project unless specifically added to it
+  #
+  # @param user [User]
+  # @param only_concrete_membership [Bool] whether require admin concrete membership status
+  def max_member_access_for_user(user, only_concrete_membership: false)
+    return ProjectMember::NO_ACCESS unless user
+    return ProjectMember::OWNER if project.owner == user
+
+    unless only_concrete_membership
+      return ProjectMember::OWNER if user.can_admin_all_resources?
+      return ProjectMember::OWNER if user.can_admin_organization?(project.organization)
+    end
+
+    max_member_access(user.id)
+  end
+
   def contribution_check_for_user_ids(user_ids)
     Gitlab::SafeRequestLoader.execute(
       resource_key: "contribution_check_for_users:#{project.id}",
