@@ -187,25 +187,34 @@ class Repository
 
   # Gitaly migration: https://gitlab.com/gitlab-org/gitaly/issues/384
   def find_commits_by_message(query, ref = nil, path = nil, limit = 1000, offset = 0)
-    unless exists? && has_visible_content? && query.present?
-      return []
-    end
+    return [] unless exists? && has_visible_content? && query.present?
 
-    commits = raw_repository.find_commits_by_message(query.strip, ref, path, limit, offset).map do |c|
-      commit(c)
-    end
+    raw_commits = raw_repository.find_commits_by_message(query.strip, ref, path, limit, offset)
+    commits = raw_commits.map { |c| commit(c) }
     CommitCollection.new(container, commits, ref)
   end
 
-  def list_commits_by(query, ref, author: nil, before: nil, after: nil, limit: 1000)
-    return [] unless exists?
-    return [] unless has_visible_content?
-    return [] unless ref.present?
+  def list_commits(
+    ref:,
+    query: nil,
+    author: nil,
+    committed_before: nil,
+    committed_after: nil,
+    pagination_params: { page_token: nil, limit: 1000 }
+  )
+    return [] unless exists? && has_visible_content? && ref.present?
 
-    commits = raw_repository.list_commits_by(
-      query, ref, author: author, before: before, after: after, limit: limit).map do |c|
-      commit(c)
-    end
+    pagination_params[:limit] ||= 1000
+
+    raw_commits = raw_repository.list_commits(
+      ref: ref,
+      query: query,
+      author: author,
+      committed_before: committed_before,
+      committed_after: committed_after,
+      pagination_params: pagination_params
+    )
+    commits = raw_commits.map { |c| commit(c) }
     CommitCollection.new(container, commits, ref)
   end
 
@@ -263,13 +272,15 @@ class Repository
     end
   end
 
-  def add_branch(user, branch_name, ref, expire_cache: true, skip_ci: false)
+  def add_branch(user, branch_name, ref, expire_cache: true, skip_ci: false, raise_on_invalid_ref: false)
     branch = raw_repository.add_branch(branch_name, user: user, target: ref, skip_ci: skip_ci)
 
     after_create_branch(expire_cache: expire_cache)
 
     branch
-  rescue Gitlab::Git::Repository::InvalidRef
+  rescue Gitlab::Git::Repository::InvalidRef => e
+    raise e if raise_on_invalid_ref
+
     false
   end
 
@@ -301,15 +312,46 @@ class Repository
     branch_names + tag_names
   end
 
+  def lazy_ref_exists?(ref_name)
+    BatchLoader.for(ref_name).batch(key: self) do |ref_names, loader, _args|
+      # Make a single Gitaly call to check all refs at once
+      existing_refs = list_refs(ref_names).to_h { |r| [r.name, true] }
+
+      # Load results for each requested ref
+      ref_names.each do |ref|
+        loader.call(ref, existing_refs.key?(ref))
+      end
+    end
+  end
+
   def branch_exists?(branch_name)
     return false unless raw_repository
 
+    if Feature.enabled?(:ref_existence_check_gitaly, project)
+      return false unless exists?
+      return false if branch_name.blank?
+
+      # Optimization: Use a root_ref cache to check the presence of the default branch
+      return true if branch_name == root_ref
+
+      Gitlab::Git::RefPreloader.preload_refs_for_project(project)
+
+      return lazy_ref_exists?(Gitlab::Git::BRANCH_REF_PREFIX + branch_name).itself
+    end
+
     branch_names_include?(branch_name)
   end
 
   def tag_exists?(tag_name)
     return false unless raw_repository
 
+    if Feature.enabled?(:ref_existence_check_gitaly, project)
+      return false unless exists?
+      return false if tag_name.blank?
+
+      return lazy_ref_exists?(Gitlab::Git::TAG_REF_PREFIX + tag_name).itself
+    end
+
     tag_names_include?(tag_name)
   end
 
@@ -358,12 +400,14 @@ class Repository
 
   def expire_tags_cache
     expire_method_caches(%i[tag_names tag_count has_ambiguous_refs?])
+    BatchLoader::Executor.clear_current if Feature.enabled?(:ref_existence_check_gitaly, project)
     @tags = nil
     @tag_names_include = nil
   end
 
   def expire_branches_cache
     expire_method_caches(%i[branch_names merged_branch_names branch_count has_visible_content? has_ambiguous_refs?])
+    BatchLoader::Executor.clear_current if Feature.enabled?(:ref_existence_check_gitaly, project)
     expire_protected_branches_cache
 
     @local_branches = nil
@@ -538,7 +582,10 @@ class Repository
 
   # Runs code after an existing branch has been removed.
   def after_remove_branch(expire_cache: true)
-    expire_branches_cache if expire_cache
+    if expire_cache
+      expire_branches_cache
+      expire_root_ref_cache
+    end
   end
 
   def lookup(sha)
@@ -874,13 +921,6 @@ class Repository
     end
   end
 
-  def move_dir_files(user, path, previous_path, **options)
-    actions = move_dir_files_actions(path, previous_path, branch_name: options[:branch_name])
-    return if actions.blank?
-
-    commit_files(user, **options.merge(actions: actions))
-  end
-
   def delete_file(user, path, **options)
     options[:actions] = [{ action: :delete, file_path: path }]
 
@@ -900,7 +940,6 @@ class Repository
 
   def commit_files(user, **options)
     start_project = options.delete(:start_project)
-
     if start_project
       options[:start_repository] = start_project.repository.raw_repository
     end
@@ -914,7 +953,7 @@ class Repository
       end
     end
 
-    with_cache_hooks { raw.commit_files(user, **options) }
+    with_cache_hooks { raw.commit_files(user, **options.merge(sign: sign_commits?)) }
   end
 
   def merge(user, source_sha, merge_request, message)
@@ -963,7 +1002,9 @@ class Repository
 
   def revert(
     user, commit, branch_name, message,
-    start_branch_name: nil, start_project: project, dry_run: false)
+    start_branch_name: nil, start_project: project, dry_run: false
+  )
+    target_sha = find_branch(branch_name)&.dereferenced_target&.id if branch_name.present?
 
     with_cache_hooks do
       raw_repository.revert(
@@ -973,7 +1014,8 @@ class Repository
         message: message,
         start_branch_name: start_branch_name,
         start_repository: start_project.repository.raw_repository,
-        dry_run: dry_run
+        dry_run: dry_run,
+        target_sha: target_sha
       )
     end
   end
@@ -981,8 +1023,8 @@ class Repository
   def cherry_pick(
     user, commit, branch_name, message,
     start_branch_name: nil, start_project: project,
-    author_name: nil, author_email: nil, dry_run: false)
-
+    author_name: nil, author_email: nil, dry_run: false
+  )
     target_sha = find_branch(branch_name)&.dereferenced_target&.id if branch_name.present?
 
     with_cache_hooks do
@@ -1019,16 +1061,16 @@ class Repository
 
   # If this method is not provided a set of branch names to check merge status,
   # it fetches all branches.
-  def merged_branch_names(branch_names = [])
+  def merged_branch_names(branch_names = [], include_identical: false)
     # Currently we should skip caching if requesting all branch names
     # This is only used in a few places, notably app/services/branches/delete_merged_service.rb,
     # and it could potentially result in a very large cache.
-    return raw_repository.merged_branch_names(branch_names) if branch_names.empty?
+    return raw_repository.merged_branch_names(branch_names, include_identical: include_identical) if branch_names.empty? || include_identical
 
     cache = redis_hash_cache
 
     merged_branch_names_hash = cache.fetch_and_add_missing(:merged_branch_names, branch_names) do |missing_branch_names, hash|
-      merged = raw_repository.merged_branch_names(missing_branch_names)
+      merged = raw_repository.merged_branch_names(missing_branch_names, include_identical: include_identical)
 
       missing_branch_names.each do |bn|
         # Redis only stores strings in hset keys, use a fancy encoder
@@ -1362,6 +1404,24 @@ class Repository
       end
   end
 
+  def granular_ref_name_update(ref)
+    if Gitlab::Git.tag_ref?(ref)
+      cache_key = 'tag_names'
+    elsif Gitlab::Git.branch_ref?(ref)
+      cache_key = 'branch_names'
+    else
+      return
+    end
+
+    cache_value = Gitlab::Git.ref_name(ref)
+
+    exists = ref_exists?(ref)
+    operation = exists ? :add : :remove
+
+    redis_set_cache.granular_update(cache_key, cache_value, operation)
+    clear_memoization(memoizable_name(cache_key))
+  end
+
   private
 
   # Increase the limit by number of excluded refs
@@ -1421,6 +1481,10 @@ class Repository
       container: container
     )
   end
+
+  def sign_commits?
+    true
+  end
 end
 
 Repository.prepend_mod_with('Repository')
