@@ -11,9 +11,12 @@ class UserDetail < ApplicationRecord
   validates :job_title, length: { maximum: 200 }
   validates :bio, length: { maximum: 255 }, allow_blank: true
 
+  validates :email_otp, length: { is: 64 }, allow_nil: true
+  validates :email_otp_last_sent_to, length: { maximum: 511 }, allow_nil: true
+
   validate :bot_namespace_user_type, if: :bot_namespace_id_changed?
 
-  ignore_column :registration_objective, remove_after: '2025-07-17', remove_with: '18.2'
+  ignore_column :skype, remove_after: '2025-09-18', remove_with: '18.4'
 
   DEFAULT_FIELD_LENGTH = 500
 
@@ -37,6 +40,18 @@ class UserDetail < ApplicationRecord
     \z            # end of string
   /x
 
+  ORCID_VALIDATION_REGEX = /
+    \A            # beginning of string
+    (             #
+      [0-9]{4}-   # 4 digits spaced by dash
+    ){3}          # 3 times
+    (             #
+    [0-9]{3}      # end with 3 digits
+    )             #
+    [0-9X]        # followed by a fourth digit or an X
+    \z            # end of string
+  /x
+
   validates :discord, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
   validate :discord_format
   validates :linkedin, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
@@ -47,17 +62,19 @@ class UserDetail < ApplicationRecord
               message: proc { s_('Profiles|must contain only a bluesky did:plc identifier.') } }
   validates :mastodon, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
   validate :mastodon_format
+  validates :orcid, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
+  validate :orcid_format
   validates :organization, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
-  validates :skype, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
   validates :twitter, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
   validates :website_url, length: { maximum: DEFAULT_FIELD_LENGTH }, url: true, allow_blank: true, if: :website_url_changed?
   validates :onboarding_status, json_schema: { filename: 'user_detail_onboarding_status' }
+  validates :github, length: { maximum: DEFAULT_FIELD_LENGTH }, allow_blank: true
 
   before_validation :sanitize_attrs
   before_save :prevent_nil_fields
 
   def sanitize_attrs
-    %i[bluesky discord linkedin mastodon skype twitter website_url].each do |attr|
+    %i[bluesky discord linkedin mastodon orcid twitter website_url github].each do |attr|
       value = self[attr]
       self[attr] = Sanitize.clean(value) if value.present?
     end
@@ -67,6 +84,15 @@ class UserDetail < ApplicationRecord
     end
   end
 
+  # Exclude the hashed email_otp attribute
+  def serializable_hash(options = nil)
+    options = options.try(:dup) || {}
+    options[:except] = Array(options[:except]).dup
+    options[:except].concat [:email_otp]
+
+    super
+  end
+
   private
 
   def prevent_nil_fields
@@ -77,9 +103,10 @@ class UserDetail < ApplicationRecord
     self.location = '' if location.nil?
     self.mastodon = '' if mastodon.nil?
     self.organization = '' if organization.nil?
-    self.skype = '' if skype.nil?
+    self.orcid = '' if orcid.nil?
     self.twitter = '' if twitter.nil?
     self.website_url = '' if website_url.nil?
+    self.github = '' if github.nil?
   end
 
   def bot_namespace_user_type
@@ -102,4 +129,10 @@ def mastodon_format
   errors.add(:mastodon, _('must contain only a mastodon handle.'))
 end
 
+def orcid_format
+  return if orcid.blank? || orcid =~ UserDetail::ORCID_VALIDATION_REGEX
+
+  errors.add(:orcid, _('must contain only a valid ORCID.'))
+end
+
 UserDetail.prepend_mod_with('UserDetail')
