@@ -1,6 +1,11 @@
 # frozen_string_literal: true
 
 class UserPreference < ApplicationRecord
+  include SafelyChangeColumnDefault
+  include IgnorableColumns
+
+  ignore_columns :home_organization_id, remove_with: '18.6', remove_after: '2025-10-18'
+
   # We could use enums, but Rails 4 doesn't support multiple
   # enum options with same name for multiple fields, also it creates
   # extra methods that aren't really needed here.
@@ -8,11 +13,16 @@ class UserPreference < ApplicationRecord
   TIME_DISPLAY_FORMATS = { system: 0, non_iso_format: 1, iso_format: 2 }.freeze
 
   belongs_to :user
-  belongs_to :home_organization, class_name: "Organizations::Organization", optional: true
+
+  columns_changing_default :text_editor_type
 
   scope :with_user, -> { joins(:user) }
   scope :gitpod_enabled, -> { where(gitpod_enabled: true) }
 
+  validates :dark_color_scheme_id, allow_nil: true, inclusion: {
+    in: Gitlab::ColorSchemes.valid_ids,
+    message: ->(*) { format(_("%{placeholder} is not a valid color scheme"), { placeholder: '%{value}' }) }
+  }
   validates :issue_notes_filter, :merge_request_notes_filter, inclusion: { in: NOTES_FILTERS.values }, presence: true
   validates :tab_width, numericality: {
     only_integer: true,
@@ -22,17 +32,20 @@ class UserPreference < ApplicationRecord
   validates :diffs_deletion_color, :diffs_addition_color,
     format: { with: ColorsHelper::HEX_COLOR_PATTERN },
     allow_blank: true
+  validate :timezone_valid, if: -> { timezone_changed? }
 
   validates :time_display_relative, allow_nil: false, inclusion: { in: [true, false] }
   validates :render_whitespace_in_code, allow_nil: false, inclusion: { in: [true, false] }
   validates :pass_user_identities_to_ci_jwt, allow_nil: false, inclusion: { in: [true, false] }
   validates :pinned_nav_items, json_schema: { filename: 'pinned_nav_items' }
+  validates :project_studio_enabled, allow_nil: false, inclusion: { in: [true, false] }
 
   validates :time_display_format, inclusion: { in: TIME_DISPLAY_FORMATS.values }, presence: true
   validates :extensions_marketplace_opt_in_url, length: { maximum: 512 }
 
-  validate :user_belongs_to_home_organization, if: :home_organization_changed?
+  validates :work_items_display_settings, json_schema: { filename: 'user_preference_work_items_display_settings' }
 
+  attribute :dark_color_scheme_id, default: -> { Gitlab::CurrentSettings.default_dark_syntax_highlighting_theme }
   attribute :tab_width, default: -> { Gitlab::TabWidth::DEFAULT }
   attribute :time_display_relative, default: true
   attribute :time_display_format, default: 0
@@ -40,6 +53,8 @@ class UserPreference < ApplicationRecord
   attribute :project_shortcut_buttons, default: true
   attribute :keyboard_shortcuts_enabled, default: true
   attribute :dpop_enabled, default: false
+  attribute :project_studio_enabled, default: false
+  attribute :text_editor_type, default: 2
 
   enum :visibility_pipeline_id_type, { id: 0, iid: 1 }, scopes: false
 
@@ -121,18 +136,14 @@ class UserPreference < ApplicationRecord
     self.text_editor = value ? "rich_text_editor" : "not_set"
   end
 
-  private
+  def timezone=(value)
+    value = nil if value == ''
 
-  def user_belongs_to_home_organization
-    # If we don't ignore the default organization id below then all users need to have their corresponding entry
-    # with default organization id as organization id in the `organization_users` table.
-    # Otherwise, the user won't be able to set the default organization as the home organization.
-    return if home_organization.default?
-    return if home_organization.user?(user)
-
-    errors.add(:user, _("is not part of the given organization"))
+    super(value)
   end
 
+  private
+
   def notes_filter_field_for(resource)
     field_key =
       if resource.is_a?(Issuable)
@@ -143,6 +154,14 @@ class UserPreference < ApplicationRecord
 
     "#{field_key}_notes_filter"
   end
+
+  def timezone_valid
+    return if timezone.nil?
+
+    return if ActiveSupport::TimeZone[timezone].present?
+
+    errors.add(:timezone, "timezone is not valid")
+  end
 end
 
 UserPreference.prepend_mod_with('UserPreference')
