@@ -2,6 +2,7 @@
 
 class SearchServicePresenter < Gitlab::View::Presenter::Delegated
   include RendersCommits
+  include RendersProjectsList
 
   presents ::SearchService, as: :search_service
 
@@ -16,7 +17,7 @@ class SearchServicePresenter < Gitlab::View::Presenter::Delegated
     blobs: :with_web_entity_associations
   }.freeze
 
-  SORT_ENABLED_SCOPES = %w(issues merge_requests epics).freeze
+  SORT_ENABLED_SCOPES = %w[issues merge_requests epics].freeze
 
   delegator_override :search_objects
   def search_objects
@@ -25,9 +26,11 @@ class SearchServicePresenter < Gitlab::View::Presenter::Delegated
 
       case scope
       when 'users'
-        objects.eager_load(:status) if objects.respond_to?(:eager_load) # rubocop:disable CodeReuse/ActiveRecord
+        objects.respond_to?(:eager_load) ? objects.eager_load(:status) : objects # rubocop:disable CodeReuse/ActiveRecord
       when 'commits'
         prepare_commits_for_rendering(objects)
+      when 'projects'
+        prepare_projects_for_rendering(objects)
       else
         objects
       end
@@ -45,4 +48,14 @@ class SearchServicePresenter < Gitlab::View::Presenter::Delegated
   def without_count?
     search_objects.is_a?(Kaminari::PaginatableWithoutCount)
   end
+
+  def advanced_search_enabled?
+    false
+  end
+
+  def zoekt_enabled?
+    false
+  end
 end
+
+SearchServicePresenter.prepend_mod_with('SearchServicePresenter')
