@@ -2,26 +2,35 @@
 
 module Ci
   class BuildCancelService
-    def initialize(build, user)
+    def initialize(build, user, force = false)
       @build = build
       @user = user
+      @force = force
     end
 
     def execute
       return forbidden unless allowed?
-      return unprocessable_entity unless build.cancelable?
+      return unprocessable_entity unless build.cancelable? || (force && allowed_to_force?)
 
-      build.cancel
+      if force
+        build.force_cancel
+      else
+        build.cancel
+      end
 
       ServiceResponse.success(payload: build)
     end
 
     private
 
-    attr_reader :build, :user
+    attr_reader :build, :user, :force
 
     def allowed?
-      user.can?(:update_build, build)
+      user.can?(:cancel_build, build)
+    end
+
+    def allowed_to_force?
+      build.force_cancelable? && user.can?(:maintainer_access, build)
     end
 
     def forbidden
