@@ -128,7 +128,7 @@ module Groups
       return false unless group.packages_feature_enabled?
 
       npm_packages = ::Packages::GroupPackagesFinder
-                       .new(current_user, group, packages_class: ::Packages::Npm::Package, preload_pipelines: false)
+                       .new(current_user, group, preload_pipelines: false, package_type: :npm)
                        .execute
 
       npm_packages = npm_packages.with_npm_scope(group.root_ancestor.path)
@@ -201,7 +201,7 @@ module Groups
 
     # rubocop: disable CodeReuse/ActiveRecord
     def update_children_and_projects_visibility
-      descendants = @group.descendants.where("visibility_level > ?", @new_parent_group.visibility_level)
+      descendants = @group.descendants.with_visibility_level_greater_than(@new_parent_group.visibility_level)
 
       Group
         .where(id: descendants.select(:id))
@@ -209,7 +209,7 @@ module Groups
 
       projects_to_update = @group
         .all_projects
-        .where("visibility_level > ?", @new_parent_group.visibility_level)
+        .with_visibility_level_greater_than(@new_parent_group.visibility_level)
 
       # Used in post_update_hooks in EE. Must use pluck (and not select)
       # here as after we perform the update below we won't be able to find
