@@ -55,7 +55,8 @@ module Groups
       # we have a path change on a root group:
       # check that we don't have any npm package with a scope set to the group path
       npm_packages = ::Packages::GroupPackagesFinder
-                       .new(current_user, group, packages_class: ::Packages::Npm::Package, preload_pipelines: false)
+                       .new(current_user, group, preload_pipelines: false,
+                         package_type: :npm)
                        .execute
                        .with_npm_scope(group.path)
 
@@ -91,8 +92,6 @@ module Groups
       end
 
       update_two_factor_requirement_for_subgroups
-
-      publish_event
     end
 
     def update_two_factor_requirement_for_subgroups
@@ -111,6 +110,10 @@ module Groups
 
     # overridden in EE
     def remove_unallowed_params
+      if Feature.disabled?(:omniauth_step_up_auth_for_namespace, group)
+        params.delete(:step_up_auth_required_oauth_provider)
+      end
+
       params.delete(:emails_enabled) unless can?(current_user, :set_emails_disabled, group)
       params.delete(:max_artifacts_size) unless can?(current_user, :update_max_artifacts_size, group)
 
@@ -144,7 +147,7 @@ module Groups
 
       crm_enabled = params.delete(:crm_enabled)
       crm_enabled = true if crm_enabled.nil?
-      crm_source_group_id = params.delete(:crm_source_group_id).presence
+      crm_source_group_id = params.delete(:crm_source_group_id).presence&.to_i
       return if group.crm_enabled? == crm_enabled && group.crm_settings&.source_group_id == crm_source_group_id
 
       if group.crm_settings&.source_group_id != crm_source_group_id && group.has_issues_with_contacts?
@@ -187,21 +190,6 @@ module Groups
       false
     end
 
-    def publish_event
-      return unless renaming?
-
-      event = Groups::GroupPathChangedEvent.new(
-        data: {
-          group_id: group.id,
-          root_namespace_id: group.root_ancestor.id,
-          old_path: @full_path_before,
-          new_path: group.full_path
-        }
-      )
-
-      Gitlab::EventStore.publish(event)
-    end
-
     def non_assignable_group_params
       []
     end
