@@ -9,6 +9,9 @@ module Namespaces
       AlreadyArchivedError = ServiceResponse.error(
         message: 'Group is already archived!'
       )
+      AncestorAlreadyArchivedError = ServiceResponse.error(
+        message: 'Cannot archive group since one of the ancestor groups is already archived!'
+      )
       ArchivingFailedError = ServiceResponse.error(
         message: 'Failed to archive group!'
       )
@@ -17,30 +20,29 @@ module Namespaces
       UpdateError = Class.new(Error)
 
       def execute
-        return NotAuthorizedError unless can?(current_user, :archive_group, group)
-        return AlreadyArchivedError if group.archived
-        return ArchivingFailedError unless group.archive
-
-        projects = GroupProjectsFinder.new(
-          group: group,
-          current_user: current_user,
-          options: { exclude_shared: true }
-        ).execute
-
-        projects.each do |project|
-          success = ::Projects::UpdateService.new(project, current_user, archived: true).execute
-
-          raise UpdateError, "Project #{project.id} can't be archived!" unless success
+        unless can?(current_user, :archive_group, group) && Feature.enabled?(:archive_group, group.root_ancestor)
+          return NotAuthorizedError
         end
 
+        return AlreadyArchivedError if group.archived
+        return AncestorAlreadyArchivedError if group.ancestors_archived?
+        return ArchivingFailedError unless group.archive
+
+        after_archive
         ServiceResponse.success
       end
 
       private
 
+      def after_archive
+        system_hook_service.execute_hooks_for(group, :update)
+      end
+
       def error_response(message)
         ServiceResponse.error(message: message)
       end
     end
   end
 end
+
+Namespaces::Groups::ArchiveService.prepend_mod
