@@ -46,10 +46,26 @@ class NotificationService
     @async ||= Async.new(self)
   end
 
-  def disabled_two_factor(user)
+  def enabled_two_factor(user, type, options = {})
     return unless user.can?(:receive_notifications)
 
-    mailer.disabled_two_factor_email(user).deliver_later
+    if type == :webauthn
+      mailer.enabled_two_factor_webauthn_email(user, options[:device_name]).deliver_later
+    else
+      mailer.enabled_two_factor_otp_email(user).deliver_later
+    end
+  end
+
+  def disabled_two_factor(user, type = :two_factor, options = {})
+    return unless user.can?(:receive_notifications)
+
+    if type == :webauthn
+      mailer.disabled_two_factor_webauthn_email(user, options[:device_name]).deliver_later
+    elsif type == :otp
+      mailer.disabled_two_factor_otp_email(user).deliver_later
+    else
+      mailer.disabled_two_factor_email(user).deliver_later
+    end
   end
 
   # Always notify user about ssh key added
