@@ -3,8 +3,6 @@
 module Packages
   module Debian
     class CreatePackageFileService
-      include ::Packages::FIPS
-
       def initialize(package:, current_user:, params: {})
         @package = package
         @current_user = current_user
@@ -12,12 +10,11 @@ module Packages
       end
 
       def execute
-        raise DisabledError, 'Debian registry is not FIPS compliant' if Gitlab::FIPS.enabled?
         raise ArgumentError, "Invalid package" unless package.present?
         raise ArgumentError, "Invalid user" unless current_user.present?
 
         # Debian package file are first uploaded to incoming with empty metadata,
-        # and are moved later by Packages::Debian::ProcessChangesService
+        # and are moved later by Packages::Debian::ProcessPackageFileService
         package_file = package.package_files.create!(
           file: params[:file],
           size: params[:file]&.size,
@@ -32,8 +29,12 @@ module Packages
           }
         )
 
-        if params[:file_name].end_with? '.changes'
-          ::Packages::Debian::ProcessChangesWorker.perform_async(package_file.id, current_user.id)
+        if end_of_new_upload?
+          ::Packages::Debian::ProcessPackageFileWorker.perform_async(
+            package_file.id,
+            params[:distribution],
+            params[:component]
+          )
         end
 
         package_file
@@ -42,6 +43,10 @@ module Packages
       private
 
       attr_reader :package, :current_user, :params
+
+      def end_of_new_upload?
+        params[:distribution].present? || params[:file_name].end_with?('.changes')
+      end
     end
   end
 end
