@@ -3,6 +3,7 @@
 module Projects
   class DestroyService < BaseService
     include Gitlab::ShellAdapter
+    include ContainerRegistry::Protection::Concerns::TagRule
 
     DestroyError = Class.new(StandardError)
     BATCH_SIZE = 100
@@ -148,8 +149,8 @@ module Projects
       # hook failed and caused us to end up here. A destroyed model will be a frozen hash,
       # which cannot be altered.
       unless project.destroyed?
-        # Restrict project visibility if the parent group visibility was made more restrictive while the project was scheduled for deletion.
-        visibility_level = project.visibility_level_allowed_by_group? ? project.visibility_level : project.group.visibility_level
+        # Restrict project visibility if the parent namespace visibility was made more restrictive while the project was scheduled for deletion.
+        visibility_level = project.visibility_level_allowed_by_namespace? ? project.visibility_level : project.namespace.visibility_level
         project.update(delete_error: message, pending_delete: false, visibility_level: visibility_level)
       end
 
@@ -229,6 +230,22 @@ module Projects
           end
         end
       end
+
+      if Feature.enabled?(:merge_request_diff_commits_dedup, project)
+        loop do
+          inner_query = MergeRequest::CommitsMetadata
+            .select(:id)
+            .where(project_id: project.id)
+            .limit(delete_batch_size)
+
+          deleted_rows = MergeRequest::CommitsMetadata
+            .where(project_id: project.id)
+            .where(id: inner_query)
+            .delete_all
+
+          break if deleted_rows == 0
+        end
+      end
     end
     # rubocop: enable CodeReuse/ActiveRecord
 
@@ -269,9 +286,28 @@ module Projects
         ::Ci::DestroySecureFileService.new(project, current_user).execute(secure_file)
       end
 
+      destroy_orphaned_ci_job_artifacts!
       delete_commit_statuses
     end
 
+    # This method will delete all orphaned CI Job artifacts for the project, which are job artifacts
+    # whose jobs do not exist anymore. The reason these artifacts might still exist is because of
+    # https://gitlab.com/gitlab-org/gitlab/-/issues/508672.
+    # TODO: remove this method after we have a working & valid FK.
+    def destroy_orphaned_ci_job_artifacts!
+      orphaned_job_artifacts = ::Ci::JobArtifact.for_project(project)
+      return if orphaned_job_artifacts.none?
+
+      service = orphaned_job_artifacts.begin_fast_destroy
+      orphaned_job_artifacts.finalize_fast_destroy(service)
+
+      Gitlab::AppLogger.info(
+        class: self.class.name,
+        project_id: project.id,
+        message: 'Orphaned CI job artifacts deleted'
+      )
+    end
+
     def delete_commit_statuses
       deleted_count = 0
 
@@ -312,13 +348,6 @@ module Projects
       )
     end
 
-    # The project can have multiple webhooks with hundreds of thousands of web_hook_logs.
-    # By default, they are removed with "DELETE CASCADE" option defined via foreign_key.
-    # But such queries can exceed the statement_timeout limit and fail to delete the project.
-    # (see https://gitlab.com/gitlab-org/gitlab/-/issues/26259)
-    #
-    # To prevent that we use WebHooks::DestroyService. It deletes logs in batches and
-    # produces smaller and faster queries to the database.
     def destroy_web_hooks!
       project.hooks.find_each do |web_hook|
         result = ::WebHooks::DestroyService.new(current_user).execute(web_hook)
@@ -345,7 +374,7 @@ module Projects
 
     def remove_registry_tags
       return true unless Gitlab.config.registry.enabled
-      return false if protected_by_tag_protection_rules?
+      return false if protected_for_delete?(project:, current_user:)
       return false unless remove_legacy_registry_tags
 
       results = []
@@ -356,19 +385,6 @@ module Projects
       results.all?
     end
 
-    def protected_by_tag_protection_rules?
-      return false if current_user.can_admin_all_resources?
-
-      return false unless project.has_container_registry_protected_tag_rules?(
-        action: 'delete',
-        access_level: project.team.max_member_access(current_user.id)
-      )
-
-      return false unless project.has_container_registry_tags?
-
-      true
-    end
-
     ##
     # This method makes sure that we correctly remove registry tags
     # for legacy image repository (when repository path equals project path).
