@@ -34,19 +34,12 @@ module Projects
       # If the block added errors, don't try to save the project
       return update_failed! if project.errors.any?
 
-      if project.update(params.except(*non_assignable_project_params))
-        after_update
+      update_project!
+      after_update
 
-        if Feature.enabled?(:destroy_fork_network_on_archive, project) &&
-            project.previous_changes[:archived] == [false, true]
-
-          UnlinkForkService.new(project, current_user).execute
-        end
-
-        success
-      else
-        update_failed!
-      end
+      success
+    rescue ActiveRecord::ActiveRecordError
+      update_failed!
     rescue ApiError => e
       error(e.message, status: :api_error)
     rescue ValidationError, Gitlab::Pages::UniqueDomainGenerationFailure => e
@@ -61,6 +54,17 @@ module Projects
 
     private
 
+    def update_project!
+      if Feature.disabled?(:replicate_deletion_schedule_operations, project)
+        return project.update!(params.except(*non_assignable_project_params))
+      end
+
+      project.transaction do
+        project.deletion_schedule&.destroy! if params[:remove_deletion_schedule]
+        project.update!(params.except(*non_assignable_project_params))
+      end
+    end
+
     def ensure_ci_cd_settings
       # It's possible that before the fix in https://gitlab.com/gitlab-org/gitlab/-/issues/421050,
       # there were projects created that has no ci_cd_settings, so we backfill it here.
@@ -93,13 +97,6 @@ module Projects
         raise_api_error(s_("UpdateProject|Changing the ci_pipeline_variables_minimum_override_role to the owner role is not allowed"))
       end
 
-      # If this is disabled via API we want to ensure we convert to the backwards compatible minimum
-      # override role 'developer'. We want to keep this attribute always "true" until removal.
-      if params[:restrict_user_defined_variables] == false
-        params[:restrict_user_defined_variables] = true
-        params[:ci_pipeline_variables_minimum_override_role] = 'developer'
-      end
-
       return if can?(current_user, :change_restrict_user_defined_variables, project)
 
       raise_api_error(s_("UpdateProject|Changing the restrict_user_defined_variables or ci_pipeline_variables_minimum_override_role is not allowed"))
@@ -133,7 +130,7 @@ module Projects
       return unless renaming_project_with_container_registry_tags?
 
       unless ContainerRegistry::GitlabApiClient.supports_gitlab_api?
-        raise ValidationError, s_('UpdateProject|Cannot rename project because it contains container registry tags!')
+        raise ValidationError, s_('UpdateProject|Cannot rename or delete project because it contains container registry tags. Delete all container registry tags first. https://docs.gitlab.com/user/packages/container_registry/#move-or-rename-container-registry-repositories')
       end
 
       dry_run = ContainerRegistry::GitlabApiClient.rename_base_repository_path(
@@ -255,7 +252,7 @@ module Projects
       new_restrict_user_defined_variables = params[:restrict_user_defined_variables]
       return false if new_restrict_user_defined_variables.nil?
 
-      project.restrict_user_defined_variables != new_restrict_user_defined_variables
+      project.restrict_user_defined_variables? != new_restrict_user_defined_variables
     end
 
     def changing_pipeline_variables_minimum_override_role?
@@ -331,36 +328,8 @@ module Projects
     end
 
     def publish_events
-      publish_project_archived_event
-      publish_project_attributed_changed_event
       publish_project_features_changed_event
-    end
-
-    def publish_project_archived_event
-      return unless project.archived_previously_changed?
-
-      event = Projects::ProjectArchivedEvent.new(data: {
-        project_id: @project.id,
-        namespace_id: @project.namespace_id,
-        root_namespace_id: @project.root_namespace.id
-      })
-
-      Gitlab::EventStore.publish(event)
-    end
-
-    def publish_project_attributed_changed_event
-      changes = @project.previous_changes
-
-      return if changes.blank?
-
-      event = Projects::ProjectAttributesChangedEvent.new(data: {
-        project_id: @project.id,
-        namespace_id: @project.namespace_id,
-        root_namespace_id: @project.root_namespace.id,
-        attributes: changes.keys
-      })
-
-      Gitlab::EventStore.publish(event)
+      publish_project_visibility_changed_event
     end
 
     def publish_project_features_changed_event
@@ -378,8 +347,21 @@ module Projects
       Gitlab::EventStore.publish(event)
     end
 
+    def publish_project_visibility_changed_event
+      return unless @project.visibility_level_previously_changed?
+
+      event = Projects::ProjectVisibilityChangedEvent.new(data: {
+        project_id: @project.id,
+        namespace_id: @project.namespace_id,
+        root_namespace_id: @project.root_namespace.id,
+        visibility_level: @project.visibility_level
+      })
+
+      Gitlab::EventStore.publish(event)
+    end
+
     def non_assignable_project_params
-      [:default_branch]
+      [:default_branch, :remove_deletion_schedule]
     end
   end
 end
