@@ -18,8 +18,7 @@ module Search
         group: group,
         order_by: params[:order_by],
         sort: params[:sort],
-        filters: filters,
-        source: params[:source]
+        filters: filters
       )
     end
 
