@@ -10,7 +10,8 @@ module ServicePing
 
     SubmissionError = Class.new(StandardError)
 
-    def initialize(payload: nil)
+    def initialize(organization:, payload: nil)
+      @organization = organization
       @payload = payload
     end
 
@@ -35,7 +36,7 @@ module ServicePing
 
     private
 
-    attr_reader :payload
+    attr_reader :payload, :organization
 
     def metadata(service_ping_payload)
       {
@@ -103,7 +104,7 @@ module ServicePing
       # rubocop: disable CodeReuse/ActiveRecord
       RawUsageData.find_or_create_by(recorded_at: usage_data[:recorded_at]) do |record|
         record.payload = usage_data
-        record.organization_id = Organizations::Organization.first.id
+        record.organization_id = organization.id
       end
       # rubocop: enable CodeReuse/ActiveRecord
     end
