@@ -10,10 +10,18 @@ module Ci
     urgency :high
 
     def perform(bridge_id)
+      Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/464668')
+
       ::Ci::Bridge.find_by_id(bridge_id).try do |bridge|
-        ::Ci::CreateDownstreamPipelineService
+        result = ::Ci::CreateDownstreamPipelineService
           .new(bridge.project, bridge.user)
           .execute(bridge)
+
+        if result.success?
+          log_extra_metadata_on_done(:new_pipeline_id, result.payload.id)
+        else
+          log_extra_metadata_on_done(:create_error_message, result.message)
+        end
       end
     end
   end
