@@ -220,10 +220,11 @@ module WorkerAttributes
     def get_concurrency_limit
       return 0 if Feature.disabled?(:sidekiq_concurrency_limit_middleware, Feature.current_request, type: :ops)
 
-      limit = get_class_attribute(:concurrency_limit)&.call.to_i
-      return limit unless limit == 0
+      limit = get_class_attribute(:concurrency_limit)&.call
+      return limit.to_i unless limit.nil?
+
       unless Feature.enabled?(:use_max_concurrency_limit_percentage_as_default_limit, Feature.current_request)
-        return limit
+        return limit.to_i # limit must be nil now, so cast it to 0
       end
 
       calculate_default_limit_from_max_percentage
