@@ -7,11 +7,11 @@ class RemoveExpiredGroupLinksWorker # rubocop:disable Scalability/IdempotentWork
 
   include CronjobQueue # rubocop:disable Scalability/CronWorkerContext
 
-  feature_category :authentication_and_authorization
+  feature_category :user_management
 
   def perform
     ProjectGroupLink.expired.find_each do |link|
-      Projects::GroupLinks::DestroyService.new(link.project, nil).execute(link)
+      Projects::GroupLinks::DestroyService.new(link.project, nil).execute(link, skip_authorization: true)
     end
 
     GroupGroupLink.expired.find_in_batches do |link_batch|
