@@ -19,8 +19,6 @@ module API
           included do
             helpers do
               def x_conan_server_capabilities_header
-                return [] unless Feature.enabled?(:conan_package_revisions_support, Feature.current_request)
-
                 ['revisions']
               end
             end
@@ -383,6 +381,7 @@ module API
                 route_setting :authorization, job_token_policies: :admin_packages
 
                 put 'authorize', urgency: :low do
+                  verify_checksum_deploy_header!
                   authorize_workhorse!(subject: project, maximum_size: project.actual_limits.conan_max_file_size)
                 end
               end
@@ -431,6 +430,7 @@ module API
                 route_setting :authorization, job_token_policies: :admin_packages
 
                 put 'authorize', urgency: :low do
+                  verify_checksum_deploy_header!
                   authorize_workhorse!(subject: project, maximum_size: project.actual_limits.conan_max_file_size)
                 end
 
