@@ -41,13 +41,12 @@ module API
         end
       end
 
-      expose :marked_for_deletion_at, if: ->(project, _) { project.adjourned_deletion? }
-      expose :marked_for_deletion_at, as: :marked_for_deletion_on, if: ->(project, _) { project.adjourned_deletion? }
+      expose :marked_for_deletion_at
+      expose :marked_for_deletion_at, as: :marked_for_deletion_on
 
       expose :packages_enabled, documentation: { type: 'boolean' }
       expose :empty_repo?, as: :empty_repo, documentation: { type: 'boolean' }
-      expose :archived?, as: :archived, documentation: { type: 'boolean' }
-      expose :visibility, documentation: { type: 'string', example: 'public' }
+      expose :self_or_ancestors_archived?, as: :archived, documentation: { type: 'boolean' }
       expose :owner, using: Entities::UserBasic, unless: ->(project, options) { project.group }
       expose :resolve_outdated_diff_discussions, documentation: { type: 'boolean' }
       expose :container_expiration_policy,
@@ -92,9 +91,11 @@ module API
       expose(:monitor_access_level, documentation: { type: 'string', example: 'enabled' }) { |project, options| project_feature_string_access_level(project, :monitor) }
       expose(:model_experiments_access_level, documentation: { type: 'string', example: 'enabled' }) { |project, options| project_feature_string_access_level(project, :model_experiments) }
       expose(:model_registry_access_level, documentation: { type: 'string', example: 'enabled' }) { |project, options| project_feature_string_access_level(project, :model_registry) }
+      expose(:package_registry_access_level, documentation: { type: 'string', example: 'enabled' }) { |project, options| project_feature_string_access_level(project, :package_registry) }
 
       expose(:emails_disabled, documentation: { type: 'boolean' }) { |project, options| project.emails_disabled? }
       expose :emails_enabled, documentation: { type: 'boolean' }
+      expose(:show_diff_preview_in_email, documentation: { type: 'boolean' }) { |project, options| project.show_diff_preview_in_email? }
 
       expose :shared_runners_enabled, documentation: { type: 'boolean' }
       expose :lfs_enabled?, as: :lfs_enabled, documentation: { type: 'boolean' }
@@ -127,10 +128,11 @@ module API
           project.build_allow_git_fetch ? 'fetch' : 'clone'
         end
         expose :keep_latest_artifacts_available?, as: :keep_latest_artifact, documentation: { type: 'boolean' }
-        expose :restrict_user_defined_variables, documentation: { type: 'boolean' }
+        expose(:restrict_user_defined_variables, documentation: { type: 'boolean' }) { |p, _| p.restrict_user_defined_variables? }
         expose :ci_pipeline_variables_minimum_override_role, documentation: { type: 'string' }
         expose :runner_token_expiration_interval, documentation: { type: 'integer', example: 3600 }
         expose :group_runners_enabled, documentation: { type: 'boolean' }
+        expose :resource_group_default_process_mode, documentation: { type: 'string', example: 'unordered' }
         expose :auto_cancel_pending_pipelines, documentation: { type: 'string', example: 'enabled' }
         expose :build_timeout, documentation: { type: 'integer', example: 3600 }
         expose :auto_devops_enabled?, as: :auto_devops_enabled, documentation: { type: 'boolean' }
@@ -162,6 +164,7 @@ module API
       expose :printing_merge_request_link_enabled, documentation: { type: 'boolean' }
       expose :merge_method, documentation: { type: 'string', example: 'merge' }
       expose :merge_request_title_regex, documentation: { type: 'string', example: '/Title of merge request/' }
+      expose :merge_request_title_regex_description, documentation: { type: 'string', example: 'This requires the title to include a Jira label' }
       expose :squash_option, documentation: { type: 'string', example: 'default_off' }
       expose :enforce_auth_checks_on_uploads, documentation: { type: 'boolean' }
       expose :suggestion_commit_message, documentation: { type: 'string', example: 'Suggestion message' }
