@@ -173,8 +173,8 @@ module API
       end
 
       def immediately_delete_subgroup_error(group)
-        if Feature.enabled?(:disallow_immediate_deletion, current_user)
-          '`permanently_remove` option is not available anymore (behind the :disallow_immediate_deletion feature flag).'
+        if !Gitlab::CurrentSettings.allow_immediate_namespaces_deletion_for_user?(current_user)
+          '`permanently_remove` option is not permitted on this instance.'
         elsif !group.subgroup?
           '`permanently_remove` option is only available for subgroups.'
         elsif !group.self_deletion_scheduled?
