@@ -7,15 +7,20 @@ module Banzai
       private
 
       def media_type
-        "video"
+        'video'
       end
 
       def safe_media_ext
         Gitlab::FileTypeDetection::SAFE_VIDEO_EXT
       end
 
-      def extra_element_attrs
-        { width: "400", preload: "metadata" }
+      def extra_element_attrs(element)
+        attrs = { preload: 'metadata' }
+
+        attrs[:height] = element[:height] if element[:height]
+        attrs[:width] = element[:width] if element[:width]
+
+        attrs
       end
     end
   end
