@@ -2,12 +2,25 @@
 
 module Gitlab
   class Blame
-    attr_accessor :blob, :commit, :range
+    include Gitlab::Utils::StrongMemoize
 
-    def initialize(blob, commit, range: nil)
+    IGNORE_REVS_FILE_NAME = '.git-blame-ignore-revs'
+
+    attr_accessor :blob, :commit, :range
+    attr_reader :blame
+
+    def initialize(blob, commit, range: nil, ignore_revs: nil)
       @blob = blob
       @commit = commit
       @range = range
+      @ignore_revs = ignore_revs
+      @blame = Gitlab::Git::Blame.new(
+        repository,
+        @commit.id,
+        @blob.path,
+        range: range,
+        ignore_revisions_blob: (default_ignore_revisions_ref if ignore_revs)
+      )
     end
 
     def first_line
@@ -20,16 +33,16 @@ module Gitlab
       current_group = nil
 
       i = first_line - 1
-      blame.each do |commit, line, previous_path|
+      blame.each do |commit, line, previous_path, span|
         commit = Commit.new(commit, project)
         commit.lazy_author # preload author
 
         if prev_sha != commit.sha
           groups << current_group if current_group
-          current_group = { commit: commit, lines: [], previous_path: previous_path }
+          current_group = { commit: commit, lines: [], previous_path: previous_path, span: span, lineno: i + 1 }
         end
 
-        current_group[:lines] << (highlight ? highlighted_lines[i].html_safe : line)
+        current_group[:lines] << (highlight && highlighted_lines[i] ? highlighted_lines[i].html_safe : line)
 
         prev_sha = commit.sha
         i += 1
@@ -41,9 +54,12 @@ module Gitlab
 
     private
 
-    def blame
-      @blame ||= Gitlab::Git::Blame.new(repository, @commit.id, @blob.path, range: range)
+    attr_reader :ignore_revs
+
+    def default_ignore_revisions_ref
+      "refs/heads/#{project.default_branch}:#{IGNORE_REVS_FILE_NAME}"
     end
+    strong_memoize_attr :default_ignore_revisions_ref
 
     def highlighted_lines
       @blob.load_all_data!
