@@ -87,6 +87,7 @@ module Gitlab
           root.variables_value
         end
       end
+      # :nocov:
       # rubocop:enable Gitlab/NoCodeCoverageComment
 
       def variables_with_data
@@ -132,7 +133,14 @@ module Gitlab
       end
 
       def normalized_jobs
-        @normalized_jobs ||= Ci::Config::Normalizer.new(jobs).normalize_jobs
+        # Remove with_actor wrapper when ci_matrix_expressions FF is removed
+        @normalized_jobs ||= Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          normalizer.normalize_jobs
+        end
+      end
+
+      def normalizer_errors
+        normalizer.errors
       end
 
       def included_templates
@@ -169,7 +177,8 @@ module Gitlab
 
       def build_config(config, inputs)
         initial_config = logger.instrument(:config_yaml_load, once: true) do
-          Config::Yaml.load!(config, inputs, @context.variables)
+          yaml_context = Config::Yaml::Context.new(variables: @context.variables)
+          Config::Yaml.load!(config, yaml_context, inputs)
         end
 
         initial_config = logger.instrument(:config_external_process, once: true) do
@@ -187,7 +196,7 @@ module Gitlab
         return initial_config unless inject_edge_stages
 
         logger.instrument(:config_stages_inject, once: true) do
-          Config::EdgeStagesInjector.new(initial_config).to_hash
+          Config::Stages.new(initial_config).inject_edge_stages!
         end
       end
 
@@ -220,6 +229,10 @@ module Gitlab
         end
       end
 
+      def normalizer
+        @normalizer ||= Ci::Config::Normalizer.new(jobs)
+      end
+
       def track_and_raise_for_dev_exception(error)
         Gitlab::ErrorTracking.track_and_raise_for_dev_exception(error, @context.sentry_payload)
       end
