@@ -13,7 +13,7 @@ module Gitlab
           :chat_data, :allow_mirror_update, :bridge, :content, :dry_run, :linting, :logger, :pipeline_policy_context,
           # These attributes are set by Chains during processing:
           :config_content, :yaml_processor_result, :workflow_rules_result, :pipeline_seed,
-          :pipeline_config, :partition_id, :inputs,
+          :pipeline_config, :partition_id, :inputs, :gitaly_context,
           keyword_init: true
         ) do
           include Gitlab::Utils::StrongMemoize
@@ -43,9 +43,7 @@ module Gitlab
           end
 
           def merge_request_ref_exists?
-            return check_merge_request_ref if Feature.enabled?(:pull_ref_directly_from_gitaly, project)
-
-            strong_memoize(:merge_request_ref_exists) { check_merge_request_ref }
+            check_merge_request_ref
           end
 
           def ref
