@@ -7,7 +7,7 @@ module Gitlab
       class Host
         attr_reader :pool, :last_checked_at, :intervals, :load_balancer, :host, :port
 
-        delegate :connection, :release_connection, :enable_query_cache!, :disable_query_cache!, :query_cache_enabled, :discarded?, to: :pool
+        delegate :release_connection, :enable_query_cache!, :disable_query_cache!, :query_cache_enabled, :discarded?, to: :pool
 
         CONNECTION_ERRORS = [
           ActionView::Template::Error,
@@ -79,6 +79,14 @@ module Gitlab
           @intervals = (interval..(interval * 2)).step(0.5).to_a
         end
 
+        def connection
+          if Gitlab.next_rails?
+            pool.lease_connection
+          else
+            pool.connection
+          end
+        end
+
         # Disconnects the pool, once all connections are no longer in use.
         #
         # timeout - The time after which the pool should be forcefully
@@ -128,10 +136,6 @@ module Gitlab
 
         # Returns true if the host is online.
         def online?
-          # Avoid using a discarded connection pool because attempting
-          # to use it will fail. After the main process forks, all of
-          # its connection pools are discarded from Rails' ForkTracker.
-          return false if discarded?
           return @online unless check_replica_status?
 
           was_online = @online
