@@ -13,13 +13,17 @@ module Gitlab
 
           def create_event(issue_event)
             attrs = {
+              importing: true,
               user_id: author_id(issue_event),
               label_id: label_finder.id_for(issue_event.label_title),
               action: action(issue_event.event),
-              created_at: issue_event.created_at
+              created_at: issue_event.created_at,
+              imported_from: imported_from
             }.merge(resource_event_belongs_to(issue_event))
 
-            ResourceLabelEvent.create!(attrs)
+            created_event = ResourceLabelEvent.create!(attrs)
+
+            push_reference(project, created_event, :user_id, issue_event[:actor]&.id)
           end
 
           def label_finder
