@@ -9,11 +9,18 @@ module Gitlab
     # config/initializers/7_redis.rb, instrumented, and used in health- & readiness checks.
     ALL_CLASSES = [
       Gitlab::Redis::Cache,
-      Gitlab::Redis::Queues,
+      Gitlab::Redis::DbLoadBalancing,
+      Gitlab::Redis::FeatureFlag,
+      *Gitlab::Redis::Queues.instances.values, # dynamically adds QueueShard* classes
+      Gitlab::Redis::QueuesMetadata,
       Gitlab::Redis::RateLimiting,
+      Gitlab::Redis::RepositoryCache,
       Gitlab::Redis::Sessions,
       Gitlab::Redis::SharedState,
-      Gitlab::Redis::TraceChunks
+      Gitlab::Redis::TraceChunks,
+      Gitlab::Redis::MemoryStoreTraceChunks,
+      Gitlab::Redis::Chat,
+      Gitlab::Redis::Workhorse
     ].freeze
   end
 end
