@@ -7,7 +7,7 @@ module Gitlab
     DEFAULT_PAGE = 1
     DEFAULT_PER_PAGE = 20
 
-    attr_reader :current_user, :query, :order_by, :sort, :filters, :source
+    attr_reader :current_user, :query, :order_by, :sort, :filters
 
     # Limit search results by passed projects
     # It allows us to search only for projects user has access to
@@ -26,8 +26,7 @@ module Gitlab
       order_by: nil,
       sort: nil,
       default_project_filter: false,
-      filters: {},
-      source: nil
+      filters: {}
     )
       @current_user = current_user
       @query = query
@@ -36,22 +35,14 @@ module Gitlab
       @order_by = order_by
       @sort = sort
       @filters = filters
-      @source = source
     end
 
-    def objects(scope, page: nil, per_page: DEFAULT_PER_PAGE, without_count: true, preload_method: nil)
+    def objects(scope, page: nil, per_page: DEFAULT_PER_PAGE, preload_method: nil)
       should_preload = preload_method.present?
       collection = collection_for(scope)
-
-      if collection.nil?
-        should_preload = false
-        collection = Kaminari.paginate_array([])
-      end
-
       collection = collection.public_send(preload_method) if should_preload # rubocop:disable GitlabSecurity/PublicSend
       collection = collection.page(page).per(per_page)
-
-      without_count ? collection.without_count : collection
+      collection.without_count
     end
 
     def formatted_count(scope)
@@ -214,15 +205,10 @@ module Gitlab
       apply_sort(issues, scope: 'issues')
     end
 
-    # rubocop: disable CodeReuse/ActiveRecord
     def milestones
       milestones = Milestone.search(query)
-
-      milestones = filter_milestones_by_project(milestones)
-
-      milestones.reorder('updated_at DESC')
+      filter_milestones_by_project(milestones).order_updated_desc
     end
-    # rubocop: enable CodeReuse/ActiveRecord
 
     def merge_requests
       merge_requests = MergeRequestsFinder.new(current_user, issuable_params).execute
