@@ -4,7 +4,7 @@ module Gitlab
   module SlashCommands
     class Command < BaseCommand
       def self.commands
-        [
+        commands = [
           Gitlab::SlashCommands::IssueShow,
           Gitlab::SlashCommands::IssueNew,
           Gitlab::SlashCommands::IssueSearch,
@@ -14,6 +14,12 @@ module Gitlab
           Gitlab::SlashCommands::Deploy,
           Gitlab::SlashCommands::Run
         ]
+
+        if Feature.enabled?(:incident_declare_slash_command)
+          commands << Gitlab::SlashCommands::IncidentManagement::IncidentNew
+        end
+
+        commands
       end
 
       def execute
