@@ -48,12 +48,6 @@ module Gitlab
             end
           end
 
-          def suggested_name
-            Gitlab::Usage::Metrics::NameSuggestion.for(:redis)
-          end
-
-          private
-
           def redis_key
             key = metric_event.dup
             key.prepend("#{prefix}_") if prefix
