@@ -16,22 +16,23 @@ module Sidebars
 
         override :active_routes
         def active_routes
-          { path: %w[groups#show groups#details] }
-        end
-
-        override :extra_nav_link_html_options
-        def extra_nav_link_html_options
-          {
-            class: 'context-header has-tooltip',
-            title: context.group.name,
-            data: { container: 'body', placement: 'right' }
-          }
+          { path: %w[groups#show groups#details groups#new projects#new] }
         end
 
         override :render?
         def render?
           true
         end
+
+        override :serialize_as_menu_item_args
+        def serialize_as_menu_item_args
+          super.merge({
+            avatar: context.group.avatar_url,
+            entity_id: context.group.id,
+            super_sidebar_parent: ::Sidebars::StaticMenu,
+            item_id: :group_overview
+          })
+        end
       end
     end
   end
