@@ -18,14 +18,6 @@ module Sidebars
           }
         end
 
-        override :extra_collapsed_container_html_options
-        def extra_collapsed_container_html_options
-          {
-            target: '_blank',
-            rel: 'noopener noreferrer'
-          }
-        end
-
         override :title
         def title
           s_('ExternalWikiService|External wiki')
@@ -41,6 +33,14 @@ module Sidebars
           external_wiki.present?
         end
 
+        override :serialize_as_menu_item_args
+        def serialize_as_menu_item_args
+          super.merge({
+            item_id: :external_wiki,
+            super_sidebar_parent: ::Sidebars::Projects::SuperSidebarMenus::PlanMenu
+          })
+        end
+
         private
 
         def external_wiki
