@@ -15,28 +15,18 @@ function update_tests_metadata() {
   cleanup_individual_job_reports
 }
 
-function retrieve_tests_mapping() {
-  mkdir -p $(dirname "$RSPEC_PACKED_TESTS_MAPPING_PATH")
-
-  if [[ ! -f "${RSPEC_PACKED_TESTS_MAPPING_PATH}" ]]; then
-    (curl --fail --location  -o "${RSPEC_PACKED_TESTS_MAPPING_PATH}.gz" "https://gitlab-org.gitlab.io/gitlab/${RSPEC_PACKED_TESTS_MAPPING_PATH}.gz" && gzip -d "${RSPEC_PACKED_TESTS_MAPPING_PATH}.gz") || echo "{}" > "${RSPEC_PACKED_TESTS_MAPPING_PATH}"
-  fi
-
-  scripts/unpack-test-mapping "${RSPEC_PACKED_TESTS_MAPPING_PATH}" "${RSPEC_TESTS_MAPPING_PATH}"
-}
-
 function retrieve_frontend_fixtures_mapping() {
-  mkdir -p $(dirname "$FRONTEND_FIXTURES_MAPPING_PATH")
+  mkdir -p $(dirname "$GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH")
 
-  if [[ ! -f "${FRONTEND_FIXTURES_MAPPING_PATH}" ]]; then
-    (curl --fail --location  -o "${FRONTEND_FIXTURES_MAPPING_PATH}" "https://gitlab-org.gitlab.io/gitlab/${FRONTEND_FIXTURES_MAPPING_PATH}") || echo "{}" > "${FRONTEND_FIXTURES_MAPPING_PATH}"
+  if [[ ! -f "${GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH}" ]]; then
+    (curl --fail --location  -o "${GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH}" "https://gitlab-org.gitlab.io/gitlab/${GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH}") || echo "{}" > "${GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH}"
   fi
 }
 
 function update_tests_mapping() {
-  pack_and_gzip_mapping "${RSPEC_TESTS_MAPPING_PATH}" "${RSPEC_PACKED_TESTS_MAPPING_PATH}" crystalball/described/rspec*.yml
+  pack_and_gzip_mapping "${GLCI_PREDICTIVE_RSPEC_TESTS_MAPPING_PATH}" "${GLCI_PREDICTIVE_RSPEC_PACKED_TESTS_MAPPING_PATH}" crystalball/described/rspec*.yml
 
-  pack_and_gzip_mapping "${RSPEC_TESTS_MAPPING_ALT_PATH}" "${RSPEC_PACKED_TESTS_MAPPING_ALT_PATH}" crystalball/coverage/rspec*.yml
+  pack_and_gzip_mapping "${GLCI_PREDICTIVE_RSPEC_TESTS_MAPPING_ALT_PATH}" "${GLCI_PREDICTIVE_RSPEC_PACKED_TESTS_MAPPING_ALT_PATH}" crystalball/coverage/rspec*.yml
 }
 
 function pack_and_gzip_mapping() {
@@ -67,7 +57,10 @@ function retrieve_failed_tests() {
 
   echo 'Generating failed tests lists...'
 
-  scripts/failed_tests.rb --previous-tests-report-path "${pipeline_report_path}" --format "${failed_tests_format}" --output-directory "${directory_for_output_reports}"
+  scripts/failed_tests.rb \
+    --previous-tests-report-path "${pipeline_report_path}" \
+    --format "${failed_tests_format}" \
+    --output-directory "${directory_for_output_reports}"
 }
 
 function rspec_args() {
@@ -151,7 +144,7 @@ function debug_rspec_variables() {
 
   echoinfo "CRYSTALBALL: ${CRYSTALBALL:-}"
 
-  echoinfo "RSPEC_TESTS_MAPPING_ENABLED: ${RSPEC_TESTS_MAPPING_ENABLED:-}"
+  echoinfo "GLCI_PREDICTIVE_RSPEC_TESTS_MAPPING_ENABLED: ${GLCI_PREDICTIVE_RSPEC_TESTS_MAPPING_ENABLED:-}"
   echoinfo "RSPEC_TESTS_FILTER_FILE: ${RSPEC_TESTS_FILTER_FILE:-}"
 }
 
@@ -274,7 +267,7 @@ function rspec_parallelized_job() {
   # e.g. 'rspec unit pg14 1/24 278964' would become 'rspec_unit_pg14_1_24_278964'
   local report_name=$(echo "${CI_JOB_NAME} ${CI_PROJECT_ID}" | sed -E 's|[/ ]|_|g')
   local rspec_opts="--force-color ${1:-}"
-  local rspec_tests_mapping_enabled="${RSPEC_TESTS_MAPPING_ENABLED:-}"
+  local rspec_tests_mapping_enabled="${GLCI_PREDICTIVE_RSPEC_TESTS_MAPPING_ENABLED:-}"
   local spec_folder_prefixes=""
   local rspec_flaky_folder_path="$(dirname "${FLAKY_RSPEC_SUITE_REPORT_PATH}")/"
   local knapsack_folder_path="$(dirname "${KNAPSACK_RSPEC_SUITE_REPORT_PATH}")/"
@@ -414,9 +407,6 @@ function retry_failed_rspec_examples() {
     exit $previous_exit_status
   fi
 
-  # Job metrics for influxDB/Grafana
-  tooling/bin/update_job_metrics_tag rspec_retried_in_new_process "true" || true
-
   # Keep track of the tests that are retried, later consolidated in a single file by the `rspec:flaky-tests-report` job
   local failed_examples=$(grep " failed" ${RSPEC_LAST_RUN_RESULTS_FILE})
   echoinfo "RSPEC_RETRIED_TESTS_REPORT_PATH: ${RSPEC_RETRIED_TESTS_REPORT_PATH:-}"
@@ -520,22 +510,6 @@ function rspec_fail_fast() {
   fi
 }
 
-function filter_rspec_matched_foss_tests() {
-  local matching_tests_file="${1}"
-  local foss_matching_tests_file="${2}"
-
-  # Keep only FOSS files that exists
-  cat ${matching_tests_file} | ruby -e 'puts $stdin.read.split(" ").select { |f| f.start_with?("spec/") && File.exist?(f) }.join(" ")' > "${foss_matching_tests_file}"
-}
-
-function filter_rspec_matched_ee_tests() {
-  local matching_tests_file="${1}"
-  local ee_matching_tests_file="${2}"
-
-  # Keep only EE files that exists
-  cat ${matching_tests_file} | ruby -e 'puts $stdin.read.split(" ").select { |f| f.start_with?("ee/spec/") && File.exist?(f) }.join(" ")' > "${ee_matching_tests_file}"
-}
-
 function generate_frontend_fixtures_mapping() {
   local pattern=""
 
@@ -555,7 +529,7 @@ function generate_frontend_fixtures_mapping() {
 
   export GENERATE_FRONTEND_FIXTURES_MAPPING="true"
 
-  mkdir -p $(dirname "$FRONTEND_FIXTURES_MAPPING_PATH")
+  mkdir -p $(dirname "$GLCI_PREDICTIVE_FRONTEND_FIXTURES_MAPPING_PATH")
 
   rspec_simple_job_with_retry "--pattern \"${pattern}\""
 }
